@@ -19,6 +19,16 @@ activate_action (GtkAction *action)
 
   GtkWidget *dialog;
 
+  if (g_str_equal (name, "DarkTheme"))
+    {
+      gboolean value = gtk_toggle_action_get_active (GTK_TOGGLE_ACTION (action));
+      GtkSettings *settings = gtk_settings_get_default ();
+
+      g_object_set (G_OBJECT (settings),
+		    "gtk-application-prefer-dark-theme", value,
+		    NULL);
+      return;
+    }
   dialog = gtk_message_dialog_new (GTK_WINDOW (window),
                                    GTK_DIALOG_DESTROY_WITH_PARENT,
                                    GTK_MESSAGE_INFO,
@@ -57,25 +67,6 @@ activate_radio_action (GtkAction *action, GtkRadioAction *current)
     }
 }
 
-static void
-activate_email (GtkAboutDialog *about,
-		const gchar    *link,
-		gpointer        data)
-{
-  gchar *text;
-  text = g_strdup_printf ("send mail to %s", link);
-  g_print ("%s\n", text);
-  g_free (text);
-}
-
-static void
-activate_url (GtkAboutDialog *about,
-	      const gchar    *link,
-	      gpointer        data)
-{
-  g_print ("show url %s\n", link);
-}
-
 static void
 about_cb (GtkAction *action,
 	  GtkWidget *window)
@@ -99,22 +90,6 @@ about_cb (GtkAction *action,
     NULL
   };
 
-  const gchar *license =
-    "This library is free software; you can redistribute it and/or\n"
-    "modify it under the terms of the GNU Library General Public License as\n"
-    "published by the Free Software Foundation; either version 2 of the\n"
-    "License, or (at your option) any later version.\n"
-    "\n"
-    "This library is distributed in the hope that it will be useful,\n"
-    "but WITHOUT ANY WARRANTY; without even the implied warranty of\n"
-    "MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU\n"
-    "Library General Public License for more details.\n"
-    "\n"
-    "You should have received a copy of the GNU Library General Public\n"
-    "License along with the Gnome Library; see the file COPYING.LIB.  If not,\n"
-    "write to the Free Software Foundation, Inc., 59 Temple Place - Suite 330,\n"
-    "Boston, MA 02111-1307, USA.\n";
-
   pixbuf = NULL;
   transparent = NULL;
   filename = demo_find_file ("gtk-logo-rgb.gif", NULL);
@@ -128,9 +103,13 @@ about_cb (GtkAction *action,
 
   gtk_show_about_dialog (GTK_WINDOW (window),
 			 "program-name", "GTK+ Code Demos",
-			 "version", PACKAGE_VERSION,
+			 "version", g_strdup_printf ("%s,\nRunning against GTK+ %d.%d.%d",
+						     PACKAGE_VERSION,
+						     gtk_get_major_version (),
+						     gtk_get_minor_version (),
+						     gtk_get_micro_version ()),
 			 "copyright", "(C) 1997-2009 The GTK+ Team",
-			 "license", license,
+			 "license-type", GTK_LICENSE_LGPL_2_1,
 			 "website", "http://www.gtk.org",
 			 "comments", "Program to demonstrate GTK+ functions.",
 			 "authors", authors,
@@ -210,6 +189,11 @@ static GtkToggleActionEntry toggle_entries[] = {
     "Bold",                                    /* tooltip */
     G_CALLBACK (activate_action),
     TRUE },                                    /* is_active */
+  { "DarkTheme", NULL,                         /* name, stock id */
+     "_Prefer Dark Theme", NULL,               /* label, accelerator */
+    "Prefer Dark Theme",                       /* tooltip */
+    G_CALLBACK (activate_action),
+    FALSE },                                   /* is_active */
 };
 static guint n_toggle_entries = G_N_ELEMENTS (toggle_entries);
 
@@ -263,6 +247,7 @@ static const gchar *ui_info =
 "      <menuitem action='Quit'/>"
 "    </menu>"
 "    <menu action='PreferencesMenu'>"
+"      <menuitem action='DarkTheme'/>"
 "      <menu action='ColorMenu'>"
 "	<menuitem action='Red'/>"
 "	<menuitem action='Green'/>"
@@ -441,7 +426,7 @@ do_appwindow (GtkWidget *do_widget)
       gtk_window_set_screen (GTK_WINDOW (window),
 			     gtk_widget_get_screen (do_widget));
       gtk_window_set_title (GTK_WINDOW (window), "Application Window");
-      gtk_window_set_icon_name (GTK_WINDOW (window), "gtk-open");
+      gtk_window_set_icon_name (GTK_WINDOW (window), "document-open");
 
       /* NULL window variable when window is closed */
       g_signal_connect (window, "destroy",
