@@ -41,15 +41,12 @@
 #include <gdk/gdkdrawable.h>
 #include <gdk/gdkenumtypes.h>
 #include <gdk/gdkevents.h>
-#include <gdk/gdkgc.h>
-#include <gdk/gdkimage.h>
 #include <gdk/gdkinput.h>
 #include <gdk/gdkkeys.h>
+#include <gdk/gdkkeysyms.h>
 #include <gdk/gdkpango.h>
 #include <gdk/gdkpixbuf.h>
-#include <gdk/gdkpixmap.h>
 #include <gdk/gdkproperty.h>
-#include <gdk/gdkrgb.h>
 #include <gdk/gdkscreen.h>
 #include <gdk/gdkselection.h>
 #include <gdk/gdkspawn.h>
@@ -83,8 +80,11 @@ void                 gdk_set_program_class (const char *program_class);
 
 /* Push and pop error handlers for X errors
  */
-void      gdk_error_trap_push           (void);
-gint      gdk_error_trap_pop            (void);
+void                           gdk_error_trap_push        (void);
+/* warn unused because you could use pop_ignored otherwise */
+G_GNUC_WARN_UNUSED_RESULT gint gdk_error_trap_pop         (void);
+void                           gdk_error_trap_pop_ignored (void);
+
 
 gchar*	                  gdk_get_display		(void);
 G_CONST_RETURN gchar*	  gdk_get_display_arg_name	(void);
@@ -154,13 +154,6 @@ void gdk_notify_startup_complete_with_id (const gchar* startup_id);
 /* Threading
  */
 
-#if !defined (GDK_DISABLE_DEPRECATED) || defined (GDK_COMPILATION)
-GDKVAR GMutex *gdk_threads_mutex; /* private */
-#endif
-
-GDKVAR GCallback gdk_threads_lock;
-GDKVAR GCallback gdk_threads_unlock;
-
 void     gdk_threads_enter                    (void);
 void     gdk_threads_leave                    (void);
 void     gdk_threads_init                     (void);
@@ -190,19 +183,8 @@ guint    gdk_threads_add_timeout_seconds      (guint          interval,
                                                GSourceFunc    function,
                                                gpointer       data);
 
-#ifdef	G_THREADS_ENABLED
-#  define GDK_THREADS_ENTER()	G_STMT_START {	\
-      if (gdk_threads_lock)                 	\
-        (*gdk_threads_lock) ();			\
-   } G_STMT_END
-#  define GDK_THREADS_LEAVE()	G_STMT_START { 	\
-      if (gdk_threads_unlock)                 	\
-        (*gdk_threads_unlock) ();		\
-   } G_STMT_END
-#else	/* !G_THREADS_ENABLED */
-#  define GDK_THREADS_ENTER()
-#  define GDK_THREADS_LEAVE()
-#endif	/* !G_THREADS_ENABLED */
+#define GDK_THREADS_ENTER() gdk_threads_enter()
+#define GDK_THREADS_LEAVE() gdk_threads_leave()
 
 G_END_DECLS
 
