@@ -278,7 +278,7 @@ gdk_display_dispose (GObject *object)
 
   _gdk_displays = g_slist_remove (_gdk_displays, object);
 
-  if (gdk_display_get_default() == display)
+  if (gdk_display_get_default () == display)
     {
       if (_gdk_displays)
         gdk_display_manager_set_default_display (gdk_display_manager_get(),
@@ -289,7 +289,13 @@ gdk_display_dispose (GObject *object)
     }
 
   if (device_manager)
-    g_signal_handlers_disconnect_by_func (device_manager, device_removed_cb, object);
+    {
+      /* this is to make it drop devices which may require using the X
+       * display and therefore can't be cleaned up in finalize.
+       * It will also disconnect device_removed_cb
+       */
+      g_object_run_dispose (G_OBJECT (display->device_manager));
+    }
 
   G_OBJECT_CLASS (gdk_display_parent_class)->dispose (object);
 }
@@ -623,7 +629,7 @@ gdk_event_send_clientmessage_toall (GdkEvent *event)
  * Return value: the core pointer device; this is owned by the
  *   display and should not be freed.
  *
- * Deprecated: 3.0: Use gdk_display_get_client_pointer() instead, or
+ * Deprecated: 3.0: Use gdk_device_manager_get_client_pointer() instead, or
  *             gdk_event_get_device() if a #GdkEvent with pointer device
  *             information is available.
  **/
@@ -644,7 +650,7 @@ gdk_device_get_core_pointer (void)
  *
  * Since: 2.2
  *
- * Deprecated: 3.0: Use gdk_display_get_client_pointer() instead, or
+ * Deprecated: 3.0: Use gdk_device_manager_get_client_pointer() instead, or
  *             gdk_event_get_device() if a #GdkEvent with device
  *             information is available.
  **/
@@ -1101,7 +1107,7 @@ singlehead_default_window_get_pointer (GdkWindow       *window,
 {
   GdkDisplay *display;
 
-  display = gdk_drawable_get_display (window);
+  display = gdk_window_get_display (window);
 
   return gdk_window_real_window_get_device_position (display,
                                                      display->core_pointer,
