@@ -66,7 +66,7 @@ typedef struct _GdkKeymapClass GdkKeymapClass;
 struct _GdkKeymap
 {
   GObject     parent_instance;
-  GdkDisplay *display;
+  GdkDisplay *GSEAL (display);
 };
 
 struct _GdkKeymapClass
@@ -108,6 +108,7 @@ gboolean       gdk_keymap_get_entries_for_keycode  (GdkKeymap           *keymap,
 PangoDirection gdk_keymap_get_direction            (GdkKeymap           *keymap);
 gboolean       gdk_keymap_have_bidi_layouts        (GdkKeymap           *keymap);
 gboolean       gdk_keymap_get_caps_lock_state      (GdkKeymap           *keymap);
+gboolean       gdk_keymap_get_num_lock_state       (GdkKeymap           *keymap);
 void           gdk_keymap_add_virtual_modifiers    (GdkKeymap           *keymap,
                                                     GdkModifierType     *state);
 gboolean       gdk_keymap_map_virtual_modifiers    (GdkKeymap           *keymap,
