@@ -36,16 +36,7 @@
 #include <glib.h>
 #include <pango/pango.h>
 #include <glib-object.h>
-
-#ifdef G_OS_WIN32
-#  ifdef GDK_COMPILATION
-#    define GDKVAR __declspec(dllexport)
-#  else
-#    define GDKVAR extern __declspec(dllimport)
-#  endif
-#else
-#  define GDKVAR extern
-#endif
+#include <cairo.h>
 
 /* The system specific file gdkconfig.h contains such configuration
  * settings that are needed not only when compiling GDK (or GTK)
@@ -60,8 +51,8 @@
 /**
  * GDK_PARENT_RELATIVE:
  *
- * A special value for #GdkPixmap variables, indicating that the background
- * pixmap for a window should be inherited from the parent window.
+ * A special value, indicating that the background
+ * for a window should be inherited from the parent window.
  */
 #define GDK_PARENT_RELATIVE  1L
 
@@ -73,9 +64,7 @@ G_BEGIN_DECLS
 /* Type definitions for the basic structures.
  */
 typedef struct _GdkPoint	      GdkPoint;
-typedef struct _GdkRectangle	      GdkRectangle;
-typedef struct _GdkSegment	      GdkSegment;
-typedef struct _GdkSpan	              GdkSpan;
+typedef cairo_rectangle_int_t	      GdkRectangle;
 
 typedef struct _GdkAtom            *GdkAtom;
 
@@ -100,25 +89,15 @@ typedef guint32 GdkNativeWindow;
 /* Forward declarations of commonly used types
  */
 typedef struct _GdkColor	      GdkColor;
-typedef struct _GdkColormap	      GdkColormap;
 typedef struct _GdkCursor	      GdkCursor;
-typedef struct _GdkFont		      GdkFont;
-typedef struct _GdkGC                 GdkGC;
-typedef struct _GdkImage              GdkImage;
-typedef struct _GdkRegion             GdkRegion;
 typedef struct _GdkVisual             GdkVisual;
 
 typedef struct _GdkDrawable           GdkDrawable;
-typedef struct _GdkDrawable           GdkBitmap;
-typedef struct _GdkDrawable           GdkPixmap;
 
 /**
  * GdkWindow:
  *
- * An opaque structure representing an onscreen drawable. Pointers to structures
- * of type #GdkPixmap, #GdkBitmap, and #GdkWindow can often be used
- * interchangeably. The type #GdkDrawable refers generically to any of these
- * types.
+ * An opaque structure representing an onscreen drawable.
  */
 typedef struct _GdkDrawable           GdkWindow;
 typedef struct _GdkDisplay	      GdkDisplay;
@@ -272,28 +251,6 @@ struct _GdkPoint
   gint y;
 };
 
-struct _GdkRectangle
-{
-  gint x;
-  gint y;
-  gint width;
-  gint height;
-};
-
-struct _GdkSegment
-{
-  gint x1;
-  gint y1;
-  gint x2;
-  gint y2;
-};
-
-struct _GdkSpan
-{
-  gint x;
-  gint y;
-  gint width;
-};
 
 G_END_DECLS
 
