@@ -65,7 +65,6 @@ typedef enum
  *  screen, and is created by the window system
  * @GDK_WINDOW_TOPLEVEL: toplevel window (used to implement #GtkWindow)
  * @GDK_WINDOW_CHILD: child window (used to implement e.g. #GtkEntry)
- * @GDK_WINDOW_DIALOG: useless/deprecated compatibility type
  * @GDK_WINDOW_TEMP: override redirect temporary window (used to implement
  *  #GtkMenu)
  * @GDK_WINDOW_FOREIGN: foreign window (see gdk_window_foreign_new())
@@ -79,7 +78,6 @@ typedef enum
   GDK_WINDOW_ROOT,
   GDK_WINDOW_TOPLEVEL,
   GDK_WINDOW_CHILD,
-  GDK_WINDOW_DIALOG,
   GDK_WINDOW_TEMP,
   GDK_WINDOW_FOREIGN,
   GDK_WINDOW_OFFSCREEN
@@ -91,7 +89,6 @@ typedef enum
  * @GDK_WA_X: Honor the X coordinate field
  * @GDK_WA_Y: Honor the Y coordinate field
  * @GDK_WA_CURSOR: Honor the cursor field
- * @GDK_WA_COLORMAP: Honor the colormap field
  * @GDK_WA_VISUAL: Honor the visual field
  * @GDK_WA_WMCLASS: Honor the wmclass_class and wmclass_name fields
  * @GDK_WA_NOREDIR: Honor the override_redirect field
@@ -110,11 +107,10 @@ typedef enum
   GDK_WA_X	   = 1 << 2,
   GDK_WA_Y	   = 1 << 3,
   GDK_WA_CURSOR	   = 1 << 4,
-  GDK_WA_COLORMAP  = 1 << 5,
-  GDK_WA_VISUAL	   = 1 << 6,
-  GDK_WA_WMCLASS   = 1 << 7,
-  GDK_WA_NOREDIR   = 1 << 8,
-  GDK_WA_TYPE_HINT = 1 << 9
+  GDK_WA_VISUAL	   = 1 << 5,
+  GDK_WA_WMCLASS   = 1 << 6,
+  GDK_WA_NOREDIR   = 1 << 7,
+  GDK_WA_TYPE_HINT = 1 << 8
 } GdkWindowAttributesType;
 
 /* Size restriction enumeration.
@@ -334,7 +330,6 @@ typedef enum
  * @wclass: #GDK_INPUT_OUTPUT (normal window) or #GDK_INPUT_ONLY (invisible
  *  window that receives events)
  * @visual: #GdkVisual for window
- * @colormap: #GdkColormap for window
  * @window_type: type of window
  * @cursor: cursor for the window (see gdk_window_set_cursor())
  * @wmclass_name: don't use (see gtk_window_set_wmclass())
@@ -353,7 +348,6 @@ struct _GdkWindowAttr
   gint height;
   GdkWindowClass wclass;
   GdkVisual *visual;
-  GdkColormap *colormap;
   GdkWindowType window_type;
   GdkCursor *cursor;
   gchar *wmclass_name;
@@ -491,68 +485,6 @@ typedef struct _GdkWindowObjectClass GdkWindowObjectClass;
 #define GDK_IS_WINDOW_CLASS(klass)   (G_TYPE_CHECK_CLASS_TYPE ((klass), GDK_TYPE_WINDOW))
 #define GDK_WINDOW_GET_CLASS(obj)    (G_TYPE_INSTANCE_GET_CLASS ((obj), GDK_TYPE_WINDOW, GdkWindowObjectClass))
 
-#ifndef GDK_DISABLE_DEPRECATED
-#define GDK_WINDOW_OBJECT(object)    ((GdkWindowObject *) GDK_WINDOW (object))
-
-#ifndef GDK_COMPILATION
-
-/* We used to export all of GdkWindowObject, but we don't want to keep doing so.
-   However, there are various parts of it accessed by macros and other code,
-   so we keep the old exported version public, but in reality it is larger. */
-
-/**** DON'T CHANGE THIS STRUCT, the real version is in gdkinternals.h ****/
-struct _GdkWindowObject
-{
-  GdkDrawable parent_instance;
-
-  GdkDrawable *GSEAL (impl); /* window-system-specific delegate object */
-  
-  GdkWindowObject *GSEAL (parent);
-
-  gpointer GSEAL (user_data);
-
-  gint GSEAL (x);
-  gint GSEAL (y);
-  
-  gint GSEAL (extension_events);
-
-  GList *GSEAL (filters);
-  GList *GSEAL (children);
-
-  GdkColor GSEAL (bg_color);
-  GdkPixmap *GSEAL (bg_pixmap);
-  
-  GSList *GSEAL (paint_stack);
-  
-  GdkRegion *GSEAL (update_area);
-  guint GSEAL (update_freeze_count);
-  
-  guint8 GSEAL (window_type);
-  guint8 GSEAL (depth);
-  guint8 GSEAL (resize_count);
-
-  GdkWindowState GSEAL (state);
-  
-  guint GSEAL (guffaw_gravity) : 1;
-  guint GSEAL (input_only) : 1;
-  guint GSEAL (modal_hint) : 1;
-  guint GSEAL (composited) : 1;
-  
-  guint GSEAL (destroyed) : 2;
-
-  guint GSEAL (accept_focus) : 1;
-  guint GSEAL (focus_on_map) : 1;
-  guint GSEAL (shaped) : 1;
-  guint GSEAL (support_multidevice) : 1;
-  
-  GdkEventMask GSEAL (event_mask);
-
-  guint GSEAL (update_and_descendants_freeze_count);
-
-  GdkWindowRedirect *GSEAL (redirect);
-};
-#endif
-#endif
 
 struct _GdkWindowObjectClass
 {
@@ -569,6 +501,9 @@ void          gdk_window_destroy               (GdkWindow     *window);
 GdkWindowType gdk_window_get_window_type       (GdkWindow     *window);
 gboolean      gdk_window_is_destroyed          (GdkWindow     *window);
 
+GdkVisual *   gdk_window_get_visual            (GdkWindow     *window);
+GdkScreen *   gdk_window_get_screen            (GdkWindow     *window);
+GdkDisplay *  gdk_window_get_display           (GdkWindow     *window);
 #ifndef GDK_MULTIDEVICE_SAFE
 GdkWindow*    gdk_window_at_pointer            (gint          *win_x,
                                                 gint          *win_y);
@@ -592,17 +527,6 @@ void          gdk_window_reparent              (GdkWindow     *window,
                                                 GdkWindow     *new_parent,
                                                 gint           x,
                                                 gint           y);
-void          gdk_window_clear                 (GdkWindow     *window);
-void          gdk_window_clear_area            (GdkWindow     *window,
-                                                gint           x,
-                                                gint           y,
-                                                gint           width,
-                                                gint           height);
-void          gdk_window_clear_area_e          (GdkWindow     *window,
-                                                gint           x,
-                                                gint           y,
-                                                gint           width,
-                                                gint           height);
 void          gdk_window_raise                 (GdkWindow     *window);
 void          gdk_window_lower                 (GdkWindow     *window);
 void          gdk_window_restack               (GdkWindow     *window,
@@ -630,7 +554,7 @@ void          gdk_window_scroll                (GdkWindow     *window,
                                                 gint           dx,
                                                 gint           dy);
 void	      gdk_window_move_region           (GdkWindow       *window,
-						const GdkRegion *region,
+						const cairo_region_t *region,
 						gint             dx,
 						gint             dy);
 gboolean      gdk_window_ensure_native        (GdkWindow       *window);
@@ -638,15 +562,9 @@ gboolean      gdk_window_ensure_native        (GdkWindow       *window);
 /* 
  * This allows for making shaped (partially transparent) windows
  * - cool feature, needed for Drag and Drag for example.
- *  The shape_mask can be the mask
- *  from gdk_pixmap_create_from_xpm.   Stefan Wille
  */
-void gdk_window_shape_combine_mask  (GdkWindow	      *window,
-                                     GdkBitmap	      *mask,
-                                     gint	       x,
-                                     gint	       y);
 void gdk_window_shape_combine_region (GdkWindow	      *window,
-                                      const GdkRegion *shape_region,
+                                      const cairo_region_t *shape_region,
                                       gint	       offset_x,
                                       gint	       offset_y);
 
@@ -672,12 +590,8 @@ void gdk_window_set_composited   (GdkWindow *window,
  */
 void gdk_window_merge_child_shapes         (GdkWindow       *window);
 
-void gdk_window_input_shape_combine_mask   (GdkWindow       *window,
-					    GdkBitmap       *mask,
-					    gint             x,
-					    gint             y);
 void gdk_window_input_shape_combine_region (GdkWindow       *window,
-                                            const GdkRegion *shape_region,
+                                            const cairo_region_t *shape_region,
                                             gint             offset_x,
                                             gint             offset_y);
 void gdk_window_set_child_input_shapes     (GdkWindow       *window);
@@ -716,6 +630,7 @@ GdkWindow*    gdk_window_lookup_for_display (GdkDisplay      *display,
 
 /* GdkWindow */
 
+gboolean      gdk_window_has_native         (GdkWindow       *window);
 void              gdk_window_set_type_hint (GdkWindow        *window,
                                             GdkWindowTypeHint hint);
 GdkWindowTypeHint gdk_window_get_type_hint (GdkWindow        *window);
@@ -739,7 +654,7 @@ void          gdk_set_sm_client_id          (const gchar        *sm_client_id);
 void	      gdk_window_begin_paint_rect   (GdkWindow          *window,
 					     const GdkRectangle *rectangle);
 void	      gdk_window_begin_paint_region (GdkWindow          *window,
-					     const GdkRegion    *region);
+					     const cairo_region_t    *region);
 void	      gdk_window_end_paint          (GdkWindow          *window);
 void	      gdk_window_flush             (GdkWindow          *window);
 
@@ -751,16 +666,12 @@ void          gdk_window_set_startup_id    (GdkWindow     *window,
 					    const gchar   *startup_id);
 void          gdk_window_set_transient_for (GdkWindow     *window,
 					    GdkWindow     *parent);
-void          gdk_window_get_background  (GdkWindow       *window,
-                                          GdkColor        *color);
 void	      gdk_window_set_background	 (GdkWindow	  *window,
 					  const GdkColor  *color);
-void	      gdk_window_get_back_pixmap (GdkWindow       *window,
-					  GdkPixmap	 **pixmap,
-					  gboolean	  *parent_relative);
-void	      gdk_window_set_back_pixmap (GdkWindow	  *window,
-					  GdkPixmap	  *pixmap,
-					  gboolean	   parent_relative);
+void	      gdk_window_set_background_pattern (GdkWindow	 *window,
+                                                 cairo_pattern_t *pattern);
+cairo_pattern_t *gdk_window_get_background_pattern (GdkWindow     *window);
+
 void	      gdk_window_set_cursor	 (GdkWindow	  *window,
 					  GdkCursor	  *cursor);
 GdkCursor    *gdk_window_get_cursor      (GdkWindow       *window);
@@ -777,6 +688,8 @@ void	      gdk_window_get_geometry	 (GdkWindow	  *window,
 					  gint		  *width,
 					  gint		  *height,
 					  gint		  *depth);
+int           gdk_window_get_width       (GdkWindow       *window);
+int           gdk_window_get_height      (GdkWindow       *window);
 void	      gdk_window_get_position	 (GdkWindow	  *window,
 					  gint		  *x,
 					  gint		  *y);
@@ -799,13 +712,6 @@ void       gdk_window_coords_from_parent (GdkWindow       *window,
                                           gdouble         *x,
                                           gdouble         *y);
 
-#if !defined (GDK_DISABLE_DEPRECATED) || defined (GTK_COMPILATION) || defined (GDK_COMPILATION)
-/* Used by gtk_handle_box_button_changed () */
-gboolean      gdk_window_get_deskrelative_origin (GdkWindow	  *window,
-					  gint		  *x,
-					  gint		  *y);
-#endif
-
 void	      gdk_window_get_root_origin (GdkWindow	  *window,
 					  gint		  *x,
 					  gint		  *y);
@@ -842,10 +748,6 @@ GdkEventMask  gdk_window_get_device_events (GdkWindow    *window,
 
 void          gdk_window_set_icon_list   (GdkWindow       *window,
 					  GList           *pixbufs);
-void	      gdk_window_set_icon	 (GdkWindow	  *window, 
-					  GdkWindow	  *icon_window,
-					  GdkPixmap	  *pixmap,
-					  GdkBitmap	  *mask);
 void	      gdk_window_set_icon_name	 (GdkWindow	  *window, 
 					  const gchar	  *name);
 void	      gdk_window_set_group	 (GdkWindow	  *window, 
@@ -858,6 +760,12 @@ gboolean      gdk_window_get_decorations (GdkWindow       *window,
 void	      gdk_window_set_functions	 (GdkWindow	  *window,
 					  GdkWMFunction	   functions);
 
+cairo_surface_t *
+              gdk_window_create_similar_surface (GdkWindow *window,
+                                          cairo_content_t  content,
+                                          int              width,
+                                          int              height);
+
 void          gdk_window_beep            (GdkWindow       *window);
 void          gdk_window_iconify         (GdkWindow       *window);
 void          gdk_window_deiconify       (GdkWindow       *window);
@@ -892,13 +800,28 @@ void       gdk_window_invalidate_rect           (GdkWindow          *window,
 					         const GdkRectangle *rect,
 					         gboolean            invalidate_children);
 void       gdk_window_invalidate_region         (GdkWindow          *window,
-					         const GdkRegion    *region,
+					         const cairo_region_t    *region,
 					         gboolean            invalidate_children);
-void       gdk_window_invalidate_maybe_recurse  (GdkWindow          *window,
-						 const GdkRegion    *region,
-						 gboolean (*child_func) (GdkWindow *, gpointer),
-						 gpointer   user_data);
-GdkRegion *gdk_window_get_update_area     (GdkWindow    *window);
+
+/**
+ * GdkWindowChildFunc:
+ * @window: a #GdkWindow
+ * @user_data: user data
+ *
+ * A function of this type is passed to gdk_window_invalidate_maybe_recurse().
+ * It gets called for each child of the window to determine whether to
+ * recursively invalidate it or now.
+ *
+ * Returns: %TRUE to invalidate @window recursively
+ */
+typedef gboolean (*GdkWindowChildFunc)          (GdkWindow *window,
+                                                 gpointer   user_data);
+
+void       gdk_window_invalidate_maybe_recurse  (GdkWindow            *window,
+						 const cairo_region_t *region,
+						 GdkWindowChildFunc    child_func,
+						 gpointer              user_data);
+cairo_region_t *gdk_window_get_update_area      (GdkWindow            *window);
 
 void       gdk_window_freeze_updates      (GdkWindow    *window);
 void       gdk_window_thaw_updates        (GdkWindow    *window);
@@ -920,11 +843,6 @@ void       gdk_window_constrain_size      (GdkGeometry  *geometry,
                                            gint         *new_width,
                                            gint         *new_height);
 
-void gdk_window_get_internal_paint_info (GdkWindow    *window,
-					 GdkDrawable **real_drawable,
-					 gint         *x_offset,
-					 gint         *y_offset);
-
 void gdk_window_enable_synchronized_configure (GdkWindow *window);
 void gdk_window_configure_finished            (GdkWindow *window);
 
@@ -935,22 +853,13 @@ GdkPointerHooks *gdk_set_pointer_hooks (const GdkPointerHooks *new_hooks);
 GdkWindow *gdk_get_default_root_window (void);
 
 /* Offscreen redirection */
-GdkPixmap *gdk_offscreen_window_get_pixmap     (GdkWindow     *window);
+cairo_surface_t *
+           gdk_offscreen_window_get_surface    (GdkWindow     *window);
 void       gdk_offscreen_window_set_embedder   (GdkWindow     *window,
 						GdkWindow     *embedder);
 GdkWindow *gdk_offscreen_window_get_embedder   (GdkWindow     *window);
 void       gdk_window_geometry_changed         (GdkWindow     *window);
 
-void       gdk_window_redirect_to_drawable   (GdkWindow     *window,
-                                              GdkDrawable   *drawable,
-                                              gint           src_x,
-                                              gint           src_y,
-                                              gint           dest_x,
-                                              gint           dest_y,
-                                              gint           width,
-                                              gint           height);
-void       gdk_window_remove_redirection     (GdkWindow     *window);
-
 /* Multidevice support */
 void       gdk_window_set_support_multidevice (GdkWindow *window,
                                                gboolean   support_multidevice);
