@@ -563,7 +563,7 @@ gdk_property_get (GdkWindow   *window,
   if (GDK_WINDOW_DESTROYED (window))
     return FALSE;
 
-  display = gdk_drawable_get_display (window);
+  display = gdk_window_get_display (window);
   xproperty = gdk_x11_atom_to_xatom_for_display (display, property);
   if (type == GDK_NONE)
     xtype = AnyPropertyType;
@@ -703,7 +703,7 @@ gdk_property_change (GdkWindow    *window,
 
   gdk_window_ensure_native (window);
 
-  display = gdk_drawable_get_display (window);
+  display = gdk_window_get_display (window);
   xproperty = gdk_x11_atom_to_xatom_for_display (display, property);
   xtype = gdk_x11_atom_to_xatom_for_display (display, type);
   xwindow = GDK_WINDOW_XID (window);
