@@ -57,6 +57,7 @@ struct _GdkScreenX11
   GdkWindow *root_window;
 
   /* Window manager */
+  long last_wmspec_check_time;
   Window wmspec_check_window;
   char *window_manager_name;
   /* TRUE if wmspec_check_window has changed since last
@@ -69,22 +70,16 @@ struct _GdkScreenX11
   guint need_refetch_wm_name : 1;
   
   /* Visual Part */
-  GdkVisualPrivate *system_visual;
-  GdkVisualPrivate **visuals;
+  GdkVisual *system_visual;
+  GdkVisual **visuals;
   gint nvisuals;
   gint available_depths[7];
   gint navailable_depths;
   GdkVisualType available_types[6];
   gint navailable_types;
   GHashTable *visual_hash;
-  GHashTable *colormap_hash;
   GdkVisual *rgba_visual;
   
-  /* Colormap Part */
-  GdkColormap *default_colormap;
-  GdkColormap *system_colormap;
-  GdkColormap *rgba_colormap;
-
   /* X settings */
   XSettingsClient *xsettings_client;
   guint xsettings_in_init : 1;
@@ -92,9 +87,10 @@ struct _GdkScreenX11
   /* Xinerama/RandR 1.2 */
   gint		 n_monitors;
   GdkX11Monitor	*monitors;
+  gint           primary_monitor;
 
-  /* Pango renderer object singleton */
-  PangoRenderer *renderer;
+  /* cache for window->translate vfunc */
+  GC subwindow_gcs[32];
 
   /* Xft resources for the display, used for default values for
    * the Xft/ XSETTINGS
@@ -121,12 +117,12 @@ GType       _gdk_screen_x11_get_type (void);
 GdkScreen * _gdk_x11_screen_new      (GdkDisplay *display,
 				      gint	  screen_number);
 
+void _gdk_x11_screen_setup                  (GdkScreen *screen);
 void _gdk_x11_screen_window_manager_changed (GdkScreen *screen);
 void _gdk_x11_screen_size_changed           (GdkScreen *screen,
 					     XEvent    *event);
-void _gdk_x11_screen_process_owner_change (GdkScreen *screen,
-					   XEvent    *event);
-void _gdk_x11_screen_process_monitors_change (GdkScreen *screen);
+void _gdk_x11_screen_process_owner_change   (GdkScreen *screen,
+					     XEvent    *event);
 
 G_END_DECLS
 
