@@ -45,18 +45,16 @@ G_BEGIN_DECLS
 #define GTK_ALIGNMENT_GET_CLASS(obj)        (G_TYPE_INSTANCE_GET_CLASS ((obj), GTK_TYPE_ALIGNMENT, GtkAlignmentClass))
 
 
-typedef struct _GtkAlignment       GtkAlignment;
-typedef struct _GtkAlignmentClass  GtkAlignmentClass;
-typedef struct _GtkAlignmentPrivate GtkAlignmentPrivate;
+typedef struct _GtkAlignment              GtkAlignment;
+typedef struct _GtkAlignmentPrivate       GtkAlignmentPrivate;
+typedef struct _GtkAlignmentClass         GtkAlignmentClass;
 
 struct _GtkAlignment
 {
   GtkBin bin;
 
-  gfloat GSEAL (xalign);
-  gfloat GSEAL (yalign);
-  gfloat GSEAL (xscale);
-  gfloat GSEAL (yscale);
+  /* <private> */
+  GtkAlignmentPrivate *priv;
 };
 
 struct _GtkAlignmentClass
