@@ -35,27 +35,34 @@
 
 G_BEGIN_DECLS
 
-/* Anchor types */
+/**
+ * GtkAlign:
+ * @GTK_ALIGN_FILL: stretch to fill all space if possible, center if
+ *     no meaningful way to stretch
+ * @GTK_ALIGN_START: snap to left or top side, leaving space on right
+ *     or bottom
+ * @GTK_ALIGN_END: snap to right or bottom side, leaving space on left
+ *     or top
+ * @GTK_ALIGN_CENTER: center natural width of widget inside the
+ *     allocation
+ *
+ * Controls how a widget deals with extra space in a single (x or y)
+ * dimension.
+ *
+ * Alignment only matters if the widget receives a "too large"
+ * allocation, for example if you packed the widget with the "expand"
+ * flag inside a #GtkBox, then the widget might get extra space.  If
+ * you have for example a 16x16 icon inside a 32x32 space, the icon
+ * could be scaled and stretched, it could be centered, or it could be
+ * positioned to one side of the space.
+ */
 typedef enum
 {
-  GTK_ANCHOR_CENTER,
-  GTK_ANCHOR_NORTH,
-  GTK_ANCHOR_NORTH_WEST,
-  GTK_ANCHOR_NORTH_EAST,
-  GTK_ANCHOR_SOUTH,
-  GTK_ANCHOR_SOUTH_WEST,
-  GTK_ANCHOR_SOUTH_EAST,
-  GTK_ANCHOR_WEST,
-  GTK_ANCHOR_EAST,
-  GTK_ANCHOR_N		= GTK_ANCHOR_NORTH,
-  GTK_ANCHOR_NW		= GTK_ANCHOR_NORTH_WEST,
-  GTK_ANCHOR_NE		= GTK_ANCHOR_NORTH_EAST,
-  GTK_ANCHOR_S		= GTK_ANCHOR_SOUTH,
-  GTK_ANCHOR_SW		= GTK_ANCHOR_SOUTH_WEST,
-  GTK_ANCHOR_SE		= GTK_ANCHOR_SOUTH_EAST,
-  GTK_ANCHOR_W		= GTK_ANCHOR_WEST,
-  GTK_ANCHOR_E		= GTK_ANCHOR_EAST
-} GtkAnchorType;
+  GTK_ALIGN_FILL,
+  GTK_ALIGN_START,
+  GTK_ALIGN_END,
+  GTK_ALIGN_CENTER
+} GtkAlign;
 
 /* Arrow placement */
 typedef enum
@@ -86,8 +93,7 @@ typedef enum
 /* Button box styles */
 typedef enum
 {
-  GTK_BUTTONBOX_DEFAULT_STYLE,
-  GTK_BUTTONBOX_SPREAD,
+  GTK_BUTTONBOX_SPREAD = 1,
   GTK_BUTTONBOX_EDGE,
   GTK_BUTTONBOX_START,
   GTK_BUTTONBOX_END,
@@ -348,8 +354,7 @@ typedef enum
   GTK_SELECTION_NONE,                             /* Nothing can be selected */
   GTK_SELECTION_SINGLE,
   GTK_SELECTION_BROWSE,
-  GTK_SELECTION_MULTIPLE,
-  GTK_SELECTION_EXTENDED = GTK_SELECTION_MULTIPLE /* Deprecated */
+  GTK_SELECTION_MULTIPLE
 } GtkSelectionMode;
 
 /* Shadow types */
@@ -372,22 +377,6 @@ typedef enum
   GTK_STATE_INSENSITIVE
 } GtkStateType;
 
-#if !defined(GTK_DISABLE_DEPRECATED) || defined (GTK_MENU_INTERNALS)
-/* Directions for submenus */
-typedef enum
-{
-  GTK_DIRECTION_LEFT,
-  GTK_DIRECTION_RIGHT
-} GtkSubmenuDirection;
-
-/* Placement of submenus */
-typedef enum
-{
-  GTK_TOP_BOTTOM,
-  GTK_LEFT_RIGHT
-} GtkSubmenuPlacement;
-#endif /* GTK_DISABLE_DEPRECATED */
-
 /* Style for toolbars */
 typedef enum
 {
@@ -405,14 +394,6 @@ typedef enum
   GTK_UPDATE_DELAYED
 } GtkUpdateType;
 
-/* Generic visibility flags */
-typedef enum
-{
-  GTK_VISIBILITY_NONE,
-  GTK_VISIBILITY_PARTIAL,
-  GTK_VISIBILITY_FULL
-} GtkVisibility;
-
 /* Window position types */
 typedef enum
 {
@@ -546,6 +527,74 @@ typedef enum
   GTK_DRAG_RESULT_ERROR
 } GtkDragResult;
 
+/**
+ * GtkSizeRequestMode:
+ * @GTK_SIZE_REQUEST_HEIGHT_FOR_WIDTH: Prefer height-for-width geometry management
+ * @GTK_SIZE_REQUEST_WIDTH_FOR_HEIGHT: Prefer width-for-height geometry management
+ * 
+ * Specifies a preference for height-for-width or
+ * width-for-height geometry management.
+ */
+typedef enum
+{
+  GTK_SIZE_REQUEST_HEIGHT_FOR_WIDTH = 0,
+  GTK_SIZE_REQUEST_WIDTH_FOR_HEIGHT
+} GtkSizeRequestMode;
+
+
+/**
+ * GtkWrapAllocationMode:
+ * @GTK_WRAP_ALLOCATE_FREE:        Items wrap freely in the box's orientation
+ * @GTK_WRAP_ALLOCATE_ALIGNED:     Items are aligned into rows and columns
+ * @GTK_WRAP_ALLOCATE_HOMOGENEOUS: Items are all allocated the same size
+ *
+ * Describes how an #GtkWrapBox positions its children.
+ */
+typedef enum {
+  GTK_WRAP_ALLOCATE_FREE = 0,
+  GTK_WRAP_ALLOCATE_ALIGNED,
+  GTK_WRAP_ALLOCATE_HOMOGENEOUS
+} GtkWrapAllocationMode;
+
+/**
+ * GtkWrapBoxSpreading:
+ * @GTK_WRAP_BOX_SPREAD_START:  Children are allocated no more than their natural size
+ *                              in the given orientation and any extra space is left trailing at 
+ *                              the end of each row/column.
+ * @GTK_WRAP_BOX_SPREAD_END:    Children are allocated no more than their natural size
+ *                              in the given orientation and any extra space skipped at the beginning
+ *                              of each row/column.
+ * @GTK_WRAP_BOX_SPREAD_EVEN:   Children are allocated no more than their natural size
+ *                              in the given orientation and any extra space is evenly distributed
+ *                              as empty space between children.
+ * @GTK_WRAP_BOX_SPREAD_EXPAND: Extra space is given to children which asked to expand in the given
+ *                              orientation (or columns/rows which contain children who asked to expand).
+ *                              If no children asked to expand; extra space is distributed evenly.
+ *
+ * Describes how a #GtkWrapBox deals with extra space in a given orientation when allocating children.
+ */
+typedef enum {
+  GTK_WRAP_BOX_SPREAD_START = 0,
+  GTK_WRAP_BOX_SPREAD_END,
+  GTK_WRAP_BOX_SPREAD_EVEN,
+  GTK_WRAP_BOX_SPREAD_EXPAND
+} GtkWrapBoxSpreading;
+
+/**
+ * GtkWrapBoxPacking:
+ * @GTK_WRAP_BOX_H_EXPAND: Whether the child expands horizontally.
+ * @GTK_WRAP_BOX_V_EXPAND: Whether the child expands vertically.
+ *
+ * Specifies how widgets will expand vertically and
+ * horizontally when placed inside a #GtkWrapBox.
+ */
+typedef enum
+{
+  GTK_WRAP_BOX_H_EXPAND = 1 << 0,
+  GTK_WRAP_BOX_V_EXPAND = 1 << 1
+} GtkWrapBoxPacking;
+
+
 G_END_DECLS
 
 #endif /* __GTK_ENUMS_H__ */
