@@ -17,7 +17,7 @@
  * Boston, MA 02111-1307, USA.
  */
 
-#if defined(GTK_DISABLE_SINGLE_INCLUDES) && !defined (__GTK_H_INSIDE__) && !defined (GTK_COMPILATION)
+#if !defined (__GTK_H_INSIDE__) && !defined (GTK_COMPILATION)
 #error "Only <gtk/gtk.h> can be included directly."
 #endif
 
@@ -26,6 +26,7 @@
 
 #include <gdk-pixbuf/gdk-pixbuf.h>
 #include <gdk/gdk.h>
+#include <gtk/gtkstyle.h>
 
 G_BEGIN_DECLS
 
@@ -48,7 +49,7 @@ struct _GtkIconTheme
   /*< private >*/
   GObject parent_instance;
 
-  GtkIconThemePrivate *GSEAL (priv);
+  GtkIconThemePrivate *priv;
 };
 
 struct _GtkIconThemeClass
@@ -102,15 +103,6 @@ typedef enum {
 
 GQuark gtk_icon_theme_error_quark (void);
 
-#ifdef G_OS_WIN32
-/* Reserve old name for DLL ABI backward compatibility */
-#define gtk_icon_theme_set_search_path gtk_icon_theme_set_search_path_utf8
-#define gtk_icon_theme_get_search_path gtk_icon_theme_get_search_path_utf8
-#define gtk_icon_theme_append_search_path gtk_icon_theme_append_search_path_utf8
-#define gtk_icon_theme_prepend_search_path gtk_icon_theme_prepend_search_path_utf8
-#define gtk_icon_info_get_filename gtk_icon_info_get_filename_utf8
-#endif
-
 GType         gtk_icon_theme_get_type              (void) G_GNUC_CONST;
 
 GtkIconTheme *gtk_icon_theme_new                   (void);
@@ -179,6 +171,18 @@ G_CONST_RETURN gchar *gtk_icon_info_get_filename       (GtkIconInfo   *icon_info
 GdkPixbuf *           gtk_icon_info_get_builtin_pixbuf (GtkIconInfo   *icon_info);
 GdkPixbuf *           gtk_icon_info_load_icon          (GtkIconInfo   *icon_info,
 							GError       **error);
+GdkPixbuf *           gtk_icon_info_load_symbolic      (GtkIconInfo   *icon_info,
+                                                        GdkColor      *fg,
+                                                        GdkColor      *success_color,
+							GdkColor      *warning_color,
+							GdkColor      *error_color,
+							gboolean      *was_symbolic,
+                                                        GError       **error);
+GdkPixbuf *           gtk_icon_info_load_symbolic_for_style  (GtkIconInfo   *icon_info,
+                                                              GtkStyle      *style,
+                                                              GtkStateType   state,
+                                                              gboolean      *was_symbolic,
+                                                              GError       **error);
 void                  gtk_icon_info_set_raw_coordinates (GtkIconInfo  *icon_info,
 							 gboolean      raw_coordinates);
 
