@@ -118,6 +118,11 @@ void _gtk_menu_shell_select_last       (GtkMenuShell *menu_shell,
 					gboolean      search_sensitive);
 void  _gtk_menu_shell_activate         (GtkMenuShell *menu_shell);
 gint  _gtk_menu_shell_get_popup_delay  (GtkMenuShell *menu_shell);
+
+void        _gtk_menu_shell_set_grab_device (GtkMenuShell *menu_shell,
+                                             GdkDevice    *device);
+GdkDevice * _gtk_menu_shell_get_grab_device (GtkMenuShell *menu_shell);
+
 void  gtk_menu_shell_cancel            (GtkMenuShell *menu_shell);
 
 void  _gtk_menu_shell_add_mnemonic     (GtkMenuShell *menu_shell,
