@@ -26,6 +26,18 @@
 #ifndef __GTK_PLUG_PRIVATE_H__
 #define __GTK_PLUG_PRIVATE_H__
 
+struct _GtkPlugPrivate
+{
+  GtkWidget      *modality_window;
+  GtkWindowGroup *modality_group;
+
+  GdkWindow      *socket_window;
+
+  GHashTable     *grabbed_keys;
+
+  guint  same_app : 1;
+};
+
 /* In gtkplug.c: */
 void _gtk_plug_send_delete_event      (GtkWidget        *widget);
 void _gtk_plug_add_all_grabbed_keys   (GtkPlug          *plug);
