@@ -29,10 +29,24 @@
 #include "gtkprinter-private.h"
 #include "gtkprintbackend.h"
 #include "gtkprintjob.h"
-#include "gtkalias.h"
 
-#define GTK_PRINTER_GET_PRIVATE(o)  \
-   (G_TYPE_INSTANCE_GET_PRIVATE ((o), GTK_TYPE_PRINTER, GtkPrinterPrivate))
+/**
+ * SECTION:gtkprinter
+ * @Short_description: Represents a printer
+ * @Title: GtkPrinter
+ *
+ * A #GtkPrinter object represents a printer. You only need to
+ * deal directly with printers if you use the non-portable
+ * #GtkPrintUnixDialog API.
+ *
+ * A #GtkPrinter allows to get status information about the printer,
+ * such as its description, its location, the number of queued jobs,
+ * etc. Most importantly, a #GtkPrinter object can be used to create
+ * a #GtkPrintJob object, which lets you print to the printer.
+ *
+ * Printing support was added in GTK+ 2.10.
+ */
+
 
 static void gtk_printer_finalize     (GObject *object);
 
@@ -131,7 +145,7 @@ gtk_printer_class_init (GtkPrinterClass *class)
                                    g_param_spec_boolean ("accepts-pdf",
 							 P_("Accepts PDF"),
 							 P_("TRUE if this printer can accept PDF"),
-							 FALSE,
+							 TRUE,
 							 GTK_PARAM_READWRITE | G_PARAM_CONSTRUCT_ONLY));
   g_object_class_install_property (G_OBJECT_CLASS (class),
                                    PROP_ACCEPTS_PS,
@@ -228,7 +242,9 @@ gtk_printer_init (GtkPrinter *printer)
 {
   GtkPrinterPrivate *priv;
 
-  priv = printer->priv = GTK_PRINTER_GET_PRIVATE (printer); 
+  priv = printer->priv = G_TYPE_INSTANCE_GET_PRIVATE (printer,
+                                                      GTK_TYPE_PRINTER,
+                                                      GtkPrinterPrivate);
 
   priv->name = NULL;
   priv->location = NULL;
@@ -240,7 +256,7 @@ gtk_printer_init (GtkPrinter *printer)
   priv->is_accepting_jobs = TRUE;
   priv->is_new = TRUE;
   priv->has_details = FALSE;
-  priv->accepts_pdf = FALSE;
+  priv->accepts_pdf = TRUE;
   priv->accepts_ps = TRUE;
 
   priv->state_message = NULL;  
@@ -398,7 +414,7 @@ gtk_printer_new (const gchar     *name,
  * 
  * Returns the backend of the printer.
  * 
- * Return value: (transfer none): the backend of @printer
+ * Return value: the backend of @printer
  * 
  * Since: 2.10
  */
@@ -779,15 +795,6 @@ gtk_printer_accepts_pdf (GtkPrinter *printer)
   return printer->priv->accepts_pdf;
 }
 
-void
-gtk_printer_set_accepts_pdf (GtkPrinter *printer,
-			     gboolean val)
-{
-  g_return_if_fail (GTK_IS_PRINTER (printer));
-
-  printer->priv->accepts_pdf = val;
-}
-
 /**
  * gtk_printer_accepts_ps:
  * @printer: a #GtkPrinter
@@ -807,15 +814,6 @@ gtk_printer_accepts_ps (GtkPrinter *printer)
   return printer->priv->accepts_ps;
 }
 
-void
-gtk_printer_set_accepts_ps (GtkPrinter *printer,
-			    gboolean val)
-{
-  g_return_if_fail (GTK_IS_PRINTER (printer));
-
-  printer->priv->accepts_ps = val;
-}
-
 gboolean
 gtk_printer_is_new (GtkPrinter *printer)
 {
@@ -1280,7 +1278,3 @@ gtk_print_capabilities_get_type (void)
 
   return etype;
 }
-
-
-#define __GTK_PRINTER_C__
-#include "gtkaliasdef.c"
