@@ -37,7 +37,6 @@
 #include "gtkprinter.h"
 #include "gtkprinter-private.h"
 #include "gtkprintbackend.h"
-#include "gtkalias.h"
 
 #ifndef O_BINARY
 #define O_BINARY 0
@@ -311,7 +310,7 @@ gtk_print_job_new (const gchar      *title,
  * 
  * Gets the #GtkPrintSettings of the print job.
  * 
- * Return value: (transfer none): the settings of @job
+ * Return value: the settings of @job
  *
  * Since: 2.10
  */
@@ -329,7 +328,7 @@ gtk_print_job_get_settings (GtkPrintJob *job)
  * 
  * Gets the #GtkPrinter of the print job.
  * 
- * Return value: (transfer none): the printer of @job
+ * Return value: the printer of @job
  *
  * Since: 2.10
  */
@@ -446,7 +445,7 @@ gtk_print_job_set_source_file (GtkPrintJob *job,
  * Gets a cairo surface onto which the pages of
  * the print job should be rendered.
  * 
- * Return value: (transfer none): the cairo surface of @job
+ * Return value: the cairo surface of @job
  *
  * Since: 2.10
  **/
@@ -486,7 +485,7 @@ gtk_print_job_get_surface (GtkPrintJob  *job,
   
 #ifdef G_ENABLE_DEBUG 
   /* If we are debugging printing don't delete the tmp files */
-  if (!(gtk_debug_flags & GTK_DEBUG_PRINTING))
+  if (!(gtk_get_debug_flags () & GTK_DEBUG_PRINTING))
 #endif /* G_ENABLE_DEBUG */
   g_unlink (filename);
   g_free (filename);
@@ -684,7 +683,3 @@ gtk_print_job_send (GtkPrintJob             *job,
 				  priv->spool_io,
                                   callback, user_data, dnotify);
 }
-
-
-#define __GTK_PRINT_JOB_C__
-#include "gtkaliasdef.c"
