@@ -31,10 +31,9 @@
 
 #include "gtkorientable.h"
 #include "gtkruler.h"
+#include "gtktypeutils.h"
 #include "gtkprivate.h"
 #include "gtkintl.h"
-#include "gtkalias.h"
-
 
 #define RULER_WIDTH           14
 #define MINIMUM_INCR          5
@@ -43,6 +42,23 @@
 
 #define ROUND(x) ((int) ((x) + 0.5))
 
+struct _GtkRulerPrivate
+{
+  GtkOrientation        orientation;
+  GtkRulerMetric       *metric;
+
+  cairo_surface_t      *backing_store;
+
+  gint                  slider_size;
+  gint                  xsrc;
+  gint                  ysrc;
+
+  gdouble               lower;          /* The upper limit of the ruler (in points) */
+  gdouble               max_size;       /* The maximum size of the ruler */
+  gdouble               position;       /* The position of the mark on the ruler */
+  gdouble               upper;          /* The lower limit of the ruler */
+};
+
 enum {
   PROP_0,
   PROP_ORIENTATION,
@@ -53,15 +69,6 @@ enum {
   PROP_METRIC
 };
 
-typedef struct _GtkRulerPrivate GtkRulerPrivate;
-
-struct _GtkRulerPrivate
-{
-  GtkOrientation orientation;
-};
-
-#define GTK_RULER_GET_PRIVATE(obj) (G_TYPE_INSTANCE_GET_PRIVATE ((obj), GTK_TYPE_RULER, GtkRulerPrivate))
-
 
 static void     gtk_ruler_set_property    (GObject        *object,
                                            guint            prop_id,
@@ -79,11 +86,14 @@ static void     gtk_ruler_size_allocate   (GtkWidget      *widget,
                                            GtkAllocation  *allocation);
 static gboolean gtk_ruler_motion_notify   (GtkWidget      *widget,
                                            GdkEventMotion *event);
-static gboolean gtk_ruler_expose          (GtkWidget      *widget,
-                                           GdkEventExpose *event);
+static gboolean gtk_ruler_draw            (GtkWidget      *widget,
+                                           cairo_t        *cr);
 static void     gtk_ruler_make_pixmap     (GtkRuler       *ruler);
-static void     gtk_ruler_real_draw_ticks (GtkRuler       *ruler);
-static void     gtk_ruler_real_draw_pos   (GtkRuler       *ruler);
+static void     gtk_ruler_draw_ticks      (GtkRuler       *ruler);
+static void     gtk_ruler_real_draw_ticks (GtkRuler       *ruler,
+                                           cairo_t        *cr);
+static void     gtk_ruler_real_draw_pos   (GtkRuler       *ruler,
+                                           cairo_t        *cr);
 
 
 static const GtkRulerMetric ruler_metrics[] =
@@ -113,7 +123,7 @@ gtk_ruler_class_init (GtkRulerClass *class)
   widget_class->size_request = gtk_ruler_size_request;
   widget_class->size_allocate = gtk_ruler_size_allocate;
   widget_class->motion_notify_event = gtk_ruler_motion_notify;
-  widget_class->expose_event = gtk_ruler_expose;
+  widget_class->draw = gtk_ruler_draw;
 
   class->draw_ticks = gtk_ruler_real_draw_ticks;
   class->draw_pos = gtk_ruler_real_draw_pos;
@@ -183,22 +193,23 @@ gtk_ruler_class_init (GtkRulerClass *class)
 static void
 gtk_ruler_init (GtkRuler *ruler)
 {
-  GtkWidget *widget = GTK_WIDGET (ruler);
-  GtkRulerPrivate *private = GTK_RULER_GET_PRIVATE (ruler);
+  GtkRulerPrivate *priv;
 
-  private->orientation = GTK_ORIENTATION_HORIZONTAL;
+  ruler->priv = G_TYPE_INSTANCE_GET_PRIVATE (ruler,
+                                             GTK_TYPE_RULER,
+                                             GtkRulerPrivate);
+  priv = ruler->priv;
 
-  widget->requisition.width  = widget->style->xthickness * 2 + 1;
-  widget->requisition.height = widget->style->ythickness * 2 + RULER_WIDTH;
+  priv->orientation = GTK_ORIENTATION_HORIZONTAL;
 
-  ruler->backing_store = NULL;
-  ruler->xsrc = 0;
-  ruler->ysrc = 0;
-  ruler->slider_size = 0;
-  ruler->lower = 0;
-  ruler->upper = 0;
-  ruler->position = 0;
-  ruler->max_size = 0;
+  priv->backing_store = NULL;
+  priv->xsrc = 0;
+  priv->ysrc = 0;
+  priv->slider_size = 0;
+  priv->lower = 0;
+  priv->upper = 0;
+  priv->position = 0;
+  priv->max_size = 0;
 
   gtk_ruler_set_metric (ruler, GTK_PIXELS);
 }
@@ -210,29 +221,29 @@ gtk_ruler_set_property (GObject      *object,
 			GParamSpec   *pspec)
 {
   GtkRuler *ruler = GTK_RULER (object);
-  GtkRulerPrivate *private = GTK_RULER_GET_PRIVATE (ruler);
+  GtkRulerPrivate *priv = ruler->priv;
 
   switch (prop_id)
     {
     case PROP_ORIENTATION:
-      private->orientation = g_value_get_enum (value);
+      priv->orientation = g_value_get_enum (value);
       gtk_widget_queue_resize (GTK_WIDGET (ruler));
       break;
     case PROP_LOWER:
-      gtk_ruler_set_range (ruler, g_value_get_double (value), ruler->upper,
-			   ruler->position, ruler->max_size);
+      gtk_ruler_set_range (ruler, g_value_get_double (value), priv->upper,
+                           priv->position, priv->max_size);
       break;
     case PROP_UPPER:
-      gtk_ruler_set_range (ruler, ruler->lower, g_value_get_double (value),
-			   ruler->position, ruler->max_size);
+      gtk_ruler_set_range (ruler, priv->lower, g_value_get_double (value),
+                           priv->position, priv->max_size);
       break;
     case PROP_POSITION:
-      gtk_ruler_set_range (ruler, ruler->lower, ruler->upper,
-			   g_value_get_double (value), ruler->max_size);
+      gtk_ruler_set_range (ruler, priv->lower, priv->upper,
+                           g_value_get_double (value), priv->max_size);
       break;
     case PROP_MAX_SIZE:
-      gtk_ruler_set_range (ruler, ruler->lower, ruler->upper,
-			   ruler->position,  g_value_get_double (value));
+      gtk_ruler_set_range (ruler, priv->lower, priv->upper,
+                           priv->position,  g_value_get_double (value));
       break;
     case PROP_METRIC:
       gtk_ruler_set_metric (ruler, g_value_get_enum (value));
@@ -250,24 +261,24 @@ gtk_ruler_get_property (GObject      *object,
 			GParamSpec   *pspec)
 {
   GtkRuler *ruler = GTK_RULER (object);
-  GtkRulerPrivate *private = GTK_RULER_GET_PRIVATE (ruler);
+  GtkRulerPrivate *priv = ruler->priv;
 
   switch (prop_id)
     {
     case PROP_ORIENTATION:
-      g_value_set_enum (value, private->orientation);
+      g_value_set_enum (value, priv->orientation);
       break;
     case PROP_LOWER:
-      g_value_set_double (value, ruler->lower);
+      g_value_set_double (value, priv->lower);
       break;
     case PROP_UPPER:
-      g_value_set_double (value, ruler->upper);
+      g_value_set_double (value, priv->upper);
       break;
     case PROP_POSITION:
-      g_value_set_double (value, ruler->position);
+      g_value_set_double (value, priv->position);
       break;
     case PROP_MAX_SIZE:
-      g_value_set_double (value, ruler->max_size);
+      g_value_set_double (value, priv->max_size);
       break;
     case PROP_METRIC:
       g_value_set_enum (value, gtk_ruler_get_metric (ruler));
@@ -278,7 +289,6 @@ gtk_ruler_get_property (GObject      *object,
     }
 }
 
-#if 0
 /**
  * gtk_ruler_new:
  * @orientation: the ruler's orientation.
@@ -287,7 +297,7 @@ gtk_ruler_get_property (GObject      *object,
  *
  * Return value: a new #GtkRuler.
  *
- * Since: 2.16
+ * Since: 3.0
  **/
 GtkWidget *
 gtk_ruler_new (GtkOrientation orientation)
@@ -296,20 +306,42 @@ gtk_ruler_new (GtkOrientation orientation)
                        "orientation", orientation,
                        NULL);
 }
-#endif
+
+/**
+ * gtk_ruler_invalidate_ticks:
+ * @ruler: the ruler to invalidate
+ *
+ * For performance reasons, #GtkRuler keeps a backbuffer containing the
+ * prerendered contents of the ticks. To cause a repaint this buffer,
+ * call this function instead of gtk_widget_queue_draw().
+ **/
+static void
+gtk_ruler_invalidate_ticks (GtkRuler *ruler)
+{
+  g_return_if_fail (GTK_IS_RULER (ruler));
+
+  if (ruler->priv->backing_store == NULL)
+    return;
+
+  gtk_ruler_draw_ticks (ruler);
+  gtk_widget_queue_draw (GTK_WIDGET (ruler));
+}
 
 void
 gtk_ruler_set_metric (GtkRuler      *ruler,
 		      GtkMetricType  metric)
 {
+  GtkRulerPrivate *priv;
+
   g_return_if_fail (GTK_IS_RULER (ruler));
 
-  ruler->metric = (GtkRulerMetric *) &ruler_metrics[metric];
+  priv = ruler->priv;
 
-  if (GTK_WIDGET_DRAWABLE (ruler))
-    gtk_widget_queue_draw (GTK_WIDGET (ruler));
+  priv->metric = (GtkRulerMetric *) &ruler_metrics[metric];
 
   g_object_notify (G_OBJECT (ruler), "metric");
+
+  gtk_ruler_invalidate_ticks (ruler);
 }
 
 /**
@@ -323,12 +355,15 @@ gtk_ruler_set_metric (GtkRuler      *ruler,
 GtkMetricType
 gtk_ruler_get_metric (GtkRuler *ruler)
 {
+  GtkRulerPrivate *priv;
   gint i;
 
   g_return_val_if_fail (GTK_IS_RULER (ruler), 0);
 
+  priv = ruler->priv;
+
   for (i = 0; i < G_N_ELEMENTS (ruler_metrics); i++)
-    if (ruler->metric == &ruler_metrics[i])
+    if (priv->metric == &ruler_metrics[i])
       return i;
 
   g_assert_not_reached ();
@@ -354,33 +389,36 @@ gtk_ruler_set_range (GtkRuler *ruler,
 		     gdouble   position,
 		     gdouble   max_size)
 {
+  GtkRulerPrivate *priv;
+
   g_return_if_fail (GTK_IS_RULER (ruler));
 
+  priv = ruler->priv;
+
   g_object_freeze_notify (G_OBJECT (ruler));
-  if (ruler->lower != lower)
+  if (priv->lower != lower)
     {
-      ruler->lower = lower;
+      priv->lower = lower;
       g_object_notify (G_OBJECT (ruler), "lower");
     }
-  if (ruler->upper != upper)
+  if (priv->upper != upper)
     {
-      ruler->upper = upper;
+      priv->upper = upper;
       g_object_notify (G_OBJECT (ruler), "upper");
     }
-  if (ruler->position != position)
+  if (priv->position != position)
     {
-      ruler->position = position;
+      priv->position = position;
       g_object_notify (G_OBJECT (ruler), "position");
     }
-  if (ruler->max_size != max_size)
+  if (priv->max_size != max_size)
     {
-      ruler->max_size = max_size;
+      priv->max_size = max_size;
       g_object_notify (G_OBJECT (ruler), "max-size");
     }
   g_object_thaw_notify (G_OBJECT (ruler));
 
-  if (GTK_WIDGET_DRAWABLE (ruler))
-    gtk_widget_queue_draw (GTK_WIDGET (ruler));
+  gtk_ruler_invalidate_ticks (ruler);
 }
 
 /**
@@ -402,67 +440,78 @@ gtk_ruler_get_range (GtkRuler *ruler,
 		     gdouble  *position,
 		     gdouble  *max_size)
 {
+  GtkRulerPrivate *priv;
+
   g_return_if_fail (GTK_IS_RULER (ruler));
 
+  priv = ruler->priv;
+
   if (lower)
-    *lower = ruler->lower;
+    *lower = priv->lower;
   if (upper)
-    *upper = ruler->upper;
+    *upper = priv->upper;
   if (position)
-    *position = ruler->position;
+    *position = priv->position;
   if (max_size)
-    *max_size = ruler->max_size;
+    *max_size = priv->max_size;
 }
 
-void
+static void
 gtk_ruler_draw_ticks (GtkRuler *ruler)
 {
+  GtkRulerPrivate *priv = ruler->priv;
+  cairo_t *cr;
+
   g_return_if_fail (GTK_IS_RULER (ruler));
 
+  if (priv->backing_store == NULL)
+    return;
+  
+  cr = cairo_create (priv->backing_store);
+
   if (GTK_RULER_GET_CLASS (ruler)->draw_ticks)
-    GTK_RULER_GET_CLASS (ruler)->draw_ticks (ruler);
+    GTK_RULER_GET_CLASS (ruler)->draw_ticks (ruler, cr);
+
+  cairo_destroy (cr);
 }
 
-void
-gtk_ruler_draw_pos (GtkRuler *ruler)
-{
-  g_return_if_fail (GTK_IS_RULER (ruler));
-
-  if (GTK_RULER_GET_CLASS (ruler)->draw_pos)
-     GTK_RULER_GET_CLASS (ruler)->draw_pos (ruler);
-}
-
-
 static void
 gtk_ruler_realize (GtkWidget *widget)
 {
+  GtkAllocation allocation;
   GtkRuler *ruler;
+  GdkWindow *window;
   GdkWindowAttr attributes;
   gint attributes_mask;
 
   ruler = GTK_RULER (widget);
-  GTK_WIDGET_SET_FLAGS (ruler, GTK_REALIZED);
+
+  gtk_widget_set_realized (widget, TRUE);
+
+  gtk_widget_get_allocation (widget, &allocation);
 
   attributes.window_type = GDK_WINDOW_CHILD;
-  attributes.x = widget->allocation.x;
-  attributes.y = widget->allocation.y;
-  attributes.width = widget->allocation.width;
-  attributes.height = widget->allocation.height;
+  attributes.x = allocation.x;
+  attributes.y = allocation.y;
+  attributes.width = allocation.width;
+  attributes.height = allocation.height;
   attributes.wclass = GDK_INPUT_OUTPUT;
   attributes.visual = gtk_widget_get_visual (widget);
-  attributes.colormap = gtk_widget_get_colormap (widget);
   attributes.event_mask = gtk_widget_get_events (widget);
   attributes.event_mask |= (GDK_EXPOSURE_MASK |
 			    GDK_POINTER_MOTION_MASK |
 			    GDK_POINTER_MOTION_HINT_MASK);
 
-  attributes_mask = GDK_WA_X | GDK_WA_Y | GDK_WA_VISUAL | GDK_WA_COLORMAP;
+  attributes_mask = GDK_WA_X | GDK_WA_Y | GDK_WA_VISUAL;
 
-  widget->window = gdk_window_new (gtk_widget_get_parent_window (widget), &attributes, attributes_mask);
-  gdk_window_set_user_data (widget->window, ruler);
+  window = gdk_window_new (gtk_widget_get_parent_window (widget),
+                           &attributes, attributes_mask);
+  gtk_widget_set_window (widget, window);
+  gdk_window_set_user_data (window, ruler);
 
-  widget->style = gtk_style_attach (widget->style, widget->window);
-  gtk_style_set_background (widget->style, widget->window, GTK_STATE_ACTIVE);
+  gtk_widget_style_attach (widget);
+  gtk_style_set_background (gtk_widget_get_style (widget),
+                            window, GTK_STATE_ACTIVE);
 
   gtk_ruler_make_pixmap (ruler);
 }
@@ -471,17 +520,12 @@ static void
 gtk_ruler_unrealize (GtkWidget *widget)
 {
   GtkRuler *ruler = GTK_RULER (widget);
+  GtkRulerPrivate *priv = ruler->priv;
 
-  if (ruler->backing_store)
+  if (priv->backing_store)
     {
-      g_object_unref (ruler->backing_store);
-      ruler->backing_store = NULL;
-    }
-
-  if (ruler->non_gr_exp_gc)
-    {
-      g_object_unref (ruler->non_gr_exp_gc);
-      ruler->non_gr_exp_gc = NULL;
+      cairo_surface_destroy (priv->backing_store);
+      priv->backing_store = NULL;
     }
 
   GTK_WIDGET_CLASS (gtk_ruler_parent_class)->unrealize (widget);
@@ -491,17 +535,21 @@ static void
 gtk_ruler_size_request (GtkWidget      *widget,
                         GtkRequisition *requisition)
 {
-  GtkRulerPrivate *private = GTK_RULER_GET_PRIVATE (widget);
+  GtkRuler *ruler = GTK_RULER (widget);
+  GtkRulerPrivate *priv = ruler->priv;
+  GtkStyle *style;
 
-  if (private->orientation == GTK_ORIENTATION_HORIZONTAL)
+  style = gtk_widget_get_style (widget);
+
+  if (priv->orientation == GTK_ORIENTATION_HORIZONTAL)
     {
-      requisition->width  = widget->style->xthickness * 2 + 1;
-      requisition->height = widget->style->ythickness * 2 + RULER_WIDTH;
+      requisition->width  = style->xthickness * 2 + 1;
+      requisition->height = style->ythickness * 2 + RULER_WIDTH;
     }
   else
     {
-      requisition->width  = widget->style->xthickness * 2 + RULER_WIDTH;
-      requisition->height = widget->style->ythickness * 2 + 1;
+      requisition->width  = style->xthickness * 2 + RULER_WIDTH;
+      requisition->height = style->ythickness * 2 + 1;
     }
 }
 
@@ -510,16 +558,23 @@ gtk_ruler_size_allocate (GtkWidget     *widget,
 			 GtkAllocation *allocation)
 {
   GtkRuler *ruler = GTK_RULER (widget);
+  GtkAllocation old_allocation;
+  gboolean resized;
 
-  widget->allocation = *allocation;
+  gtk_widget_get_allocation (widget, &old_allocation);
+  resized = (old_allocation.width != allocation->width ||
+             old_allocation.height != allocation->height);
 
-  if (GTK_WIDGET_REALIZED (widget))
+  gtk_widget_set_allocation (widget, allocation);
+
+  if (gtk_widget_get_realized (widget))
     {
-      gdk_window_move_resize (widget->window,
+      gdk_window_move_resize (gtk_widget_get_window (widget),
 			      allocation->x, allocation->y,
 			      allocation->width, allocation->height);
 
-      gtk_ruler_make_pixmap (ruler);
+      if (resized)
+        gtk_ruler_make_pixmap (ruler);
     }
 }
 
@@ -527,8 +582,9 @@ static gboolean
 gtk_ruler_motion_notify (GtkWidget      *widget,
                          GdkEventMotion *event)
 {
+  GtkAllocation allocation;
   GtkRuler *ruler = GTK_RULER (widget);
-  GtkRulerPrivate *private = GTK_RULER_GET_PRIVATE (widget);
+  GtkRulerPrivate *priv = ruler->priv;
   gint x;
   gint y;
 
@@ -536,39 +592,31 @@ gtk_ruler_motion_notify (GtkWidget      *widget,
   x = event->x;
   y = event->y;
 
-  if (private->orientation == GTK_ORIENTATION_HORIZONTAL)
-    ruler->position = ruler->lower + ((ruler->upper - ruler->lower) * x) / widget->allocation.width;
+  gtk_widget_get_allocation (widget, &allocation);
+  if (priv->orientation == GTK_ORIENTATION_HORIZONTAL)
+    priv->position = priv->lower + ((priv->upper - priv->lower) * x) / allocation.width;
   else
-    ruler->position = ruler->lower + ((ruler->upper - ruler->lower) * y) / widget->allocation.height;
+    priv->position = priv->lower + ((priv->upper - priv->lower) * y) / allocation.height;
 
   g_object_notify (G_OBJECT (ruler), "position");
 
-  /*  Make sure the ruler has been allocated already  */
-  if (ruler->backing_store != NULL)
-    gtk_ruler_draw_pos (ruler);
+  gtk_widget_queue_draw (widget);
 
   return FALSE;
 }
 
 static gboolean
-gtk_ruler_expose (GtkWidget      *widget,
-		  GdkEventExpose *event)
+gtk_ruler_draw (GtkWidget *widget,
+                cairo_t   *cr)
 {
-  if (GTK_WIDGET_DRAWABLE (widget))
-    {
-      GtkRuler *ruler = GTK_RULER (widget);
+  GtkRuler *ruler = GTK_RULER (widget);
+  GtkRulerPrivate *priv = ruler->priv;
 
-      gtk_ruler_draw_ticks (ruler);
-      
-      gdk_draw_drawable (widget->window,
-			 ruler->non_gr_exp_gc,
-			 ruler->backing_store,
-			 0, 0, 0, 0,
-			 widget->allocation.width,
-			 widget->allocation.height);
-      
-      gtk_ruler_draw_pos (ruler);
-    }
+  cairo_set_source_surface (cr, priv->backing_store, 0, 0);
+  cairo_paint (cr);
+  
+  if (GTK_RULER_GET_CLASS (ruler)->draw_pos)
+     GTK_RULER_GET_CLASS (ruler)->draw_pos (ruler, cr);
 
   return FALSE;
 }
@@ -576,44 +624,37 @@ gtk_ruler_expose (GtkWidget      *widget,
 static void
 gtk_ruler_make_pixmap (GtkRuler *ruler)
 {
+  GtkRulerPrivate *priv = ruler->priv;
+  GtkAllocation allocation;
   GtkWidget *widget;
-  gint width;
-  gint height;
 
   widget = GTK_WIDGET (ruler);
 
-  if (ruler->backing_store)
-    {
-      gdk_drawable_get_size (ruler->backing_store, &width, &height);
-      if ((width == widget->allocation.width) &&
-	  (height == widget->allocation.height))
-	return;
+  gtk_widget_get_allocation (widget, &allocation);
 
-      g_object_unref (ruler->backing_store);
-    }
+  if (priv->backing_store)
+    cairo_surface_destroy (priv->backing_store);
 
-  ruler->backing_store = gdk_pixmap_new (widget->window,
-					 widget->allocation.width,
-					 widget->allocation.height,
-					 -1);
+  priv->backing_store = gdk_window_create_similar_surface (gtk_widget_get_window (widget),
+                                                           CAIRO_CONTENT_COLOR,
+                                                           allocation.width,
+                                                           allocation.height);
 
-  ruler->xsrc = 0;
-  ruler->ysrc = 0;
+  priv->xsrc = 0;
+  priv->ysrc = 0;
 
-  if (!ruler->non_gr_exp_gc)
-    {
-      ruler->non_gr_exp_gc = gdk_gc_new (widget->window);
-      gdk_gc_set_exposures (ruler->non_gr_exp_gc, FALSE);
-    }
+  gtk_ruler_draw_ticks (ruler);
 }
 
 static void
-gtk_ruler_real_draw_ticks (GtkRuler *ruler)
+gtk_ruler_real_draw_ticks (GtkRuler *ruler,
+                           cairo_t  *cr)
 {
   GtkWidget *widget = GTK_WIDGET (ruler);
-  GtkRulerPrivate *private = GTK_RULER_GET_PRIVATE (ruler);
-  cairo_t *cr;
+  GtkRulerPrivate *priv = ruler->priv;
+  GtkStyle *style;
   gint i, j;
+  gint w, h;
   gint width, height;
   gint xthickness;
   gint ythickness;
@@ -632,11 +673,10 @@ gtk_ruler_real_draw_ticks (GtkRuler *ruler)
   PangoLayout *layout;
   PangoRectangle logical_rect, ink_rect;
 
-  if (!GTK_WIDGET_DRAWABLE (ruler))
-    return;
+  style = gtk_widget_get_style (widget);
 
-  xthickness = widget->style->xthickness;
-  ythickness = widget->style->ythickness;
+  xthickness = style->xthickness;
+  ythickness = style->ythickness;
 
   layout = gtk_widget_create_pango_layout (widget, "012456789");
   pango_layout_get_extents (layout, &ink_rect, &logical_rect);
@@ -644,36 +684,38 @@ gtk_ruler_real_draw_ticks (GtkRuler *ruler)
   digit_height = PANGO_PIXELS (ink_rect.height) + 2;
   digit_offset = ink_rect.y;
 
-  if (private->orientation == GTK_ORIENTATION_HORIZONTAL)
+  w = gtk_widget_get_allocated_width (widget);
+  h = gtk_widget_get_allocated_height (widget);
+
+  if (priv->orientation == GTK_ORIENTATION_HORIZONTAL)
     {
-      width = widget->allocation.width;
-      height = widget->allocation.height - ythickness * 2;
+      width = w;
+      height = h - ythickness * 2;
     }
   else
     {
-      width = widget->allocation.height;
-      height = widget->allocation.width - ythickness * 2;
+      width = h;
+      height = w - ythickness * 2;
     }
 
-#define DETAILE(private) (private->orientation == GTK_ORIENTATION_HORIZONTAL ? "hruler" : "vruler");
+#define DETAILE(private) (priv->orientation == GTK_ORIENTATION_HORIZONTAL ? "hruler" : "vruler");
 
-  gtk_paint_box (widget->style, ruler->backing_store,
-		 GTK_STATE_NORMAL, GTK_SHADOW_OUT,
-		 NULL, widget,
-                 private->orientation == GTK_ORIENTATION_HORIZONTAL ?
-                 "hruler" : "vruler",
-		 0, 0,
-		 widget->allocation.width, widget->allocation.height);
+  gdk_cairo_set_source_color (cr, &style->fg[gtk_widget_get_state (widget)]);
 
-  cr = gdk_cairo_create (ruler->backing_store);
-  gdk_cairo_set_source_color (cr, &widget->style->fg[widget->state]);
+  gtk_paint_box (style, cr,
+                       GTK_STATE_NORMAL, GTK_SHADOW_OUT,
+                       widget,
+                       priv->orientation == GTK_ORIENTATION_HORIZONTAL ?
+                       "hruler" : "vruler",
+                       0, 0,
+                       w, h);
 
-  if (private->orientation == GTK_ORIENTATION_HORIZONTAL)
+  if (priv->orientation == GTK_ORIENTATION_HORIZONTAL)
     {
       cairo_rectangle (cr,
                        xthickness,
                        height + ythickness,
-                       widget->allocation.width - 2 * xthickness,
+                       w - 2 * xthickness,
                        1);
     }
   else
@@ -682,11 +724,11 @@ gtk_ruler_real_draw_ticks (GtkRuler *ruler)
                        height + xthickness,
                        ythickness,
                        1,
-                       widget->allocation.height - 2 * ythickness);
+                       h - 2 * ythickness);
     }
 
-  upper = ruler->upper / ruler->metric->pixels_per_unit;
-  lower = ruler->lower / ruler->metric->pixels_per_unit;
+  upper = priv->upper / priv->metric->pixels_per_unit;
+  lower = priv->lower / priv->metric->pixels_per_unit;
 
   if ((upper - lower) == 0)
     goto out;
@@ -694,8 +736,7 @@ gtk_ruler_real_draw_ticks (GtkRuler *ruler)
   increment = (gdouble) width / (upper - lower);
 
   /* determine the scale H
-   *  We calculate the text size as for the vruler instead of using
-   *  text_width = gdk_string_width(font, unit_str), so that the result
+   *  We calculate the text size as for the vruler, so that the result
    *  for the scale looks consistent with an accompanying vruler
    */
   /* determine the scale V
@@ -704,15 +745,15 @@ gtk_ruler_real_draw_ticks (GtkRuler *ruler)
    *   of this displayed text. Use this height to find a scale which
    *   leaves sufficient room for drawing the ruler.
    */
-  scale = ceil (ruler->max_size / ruler->metric->pixels_per_unit);
+  scale = ceil (priv->max_size / priv->metric->pixels_per_unit);
   g_snprintf (unit_str, sizeof (unit_str), "%d", scale);
 
-  if (private->orientation == GTK_ORIENTATION_HORIZONTAL)
+  if (priv->orientation == GTK_ORIENTATION_HORIZONTAL)
     {
       text_width = strlen (unit_str) * digit_height + 1;
 
       for (scale = 0; scale < MAXIMUM_SCALES; scale++)
-        if (ruler->metric->ruler_scale[scale] * fabs(increment) > 2 * text_width)
+        if (priv->metric->ruler_scale[scale] * fabs(increment) > 2 * text_width)
           break;
     }
   else
@@ -720,7 +761,7 @@ gtk_ruler_real_draw_ticks (GtkRuler *ruler)
       text_height = strlen (unit_str) * digit_height + 1;
 
       for (scale = 0; scale < MAXIMUM_SCALES; scale++)
-        if (ruler->metric->ruler_scale[scale] * fabs(increment) > 2 * text_height)
+        if (priv->metric->ruler_scale[scale] * fabs(increment) > 2 * text_height)
           break;
     }
 
@@ -731,8 +772,8 @@ gtk_ruler_real_draw_ticks (GtkRuler *ruler)
   length = 0;
   for (i = MAXIMUM_SUBDIVIDE - 1; i >= 0; i--)
     {
-      subd_incr = (gdouble) ruler->metric->ruler_scale[scale] /
-	          (gdouble) ruler->metric->subdivide[i];
+      subd_incr = (gdouble) priv->metric->ruler_scale[scale] /
+	          (gdouble) priv->metric->subdivide[i];
       if (subd_incr * fabs(increment) <= MINIMUM_INCR)
 	continue;
 
@@ -758,7 +799,7 @@ gtk_ruler_real_draw_ticks (GtkRuler *ruler)
 	{
 	  pos = ROUND ((cur - lower) * increment);
 
-          if (private->orientation == GTK_ORIENTATION_HORIZONTAL)
+          if (priv->orientation == GTK_ORIENTATION_HORIZONTAL)
             {
               cairo_rectangle (cr,
                                pos, height + ythickness - length,
@@ -770,26 +811,26 @@ gtk_ruler_real_draw_ticks (GtkRuler *ruler)
                                height + xthickness - length, pos,
                                length,                       1);
             }
+          cairo_fill (cr);
 
 	  /* draw label */
 	  if (i == 0)
 	    {
 	      g_snprintf (unit_str, sizeof (unit_str), "%d", (int) cur);
 
-              if (private->orientation == GTK_ORIENTATION_HORIZONTAL)
+              if (priv->orientation == GTK_ORIENTATION_HORIZONTAL)
                 {
                   pango_layout_set_text (layout, unit_str, -1);
                   pango_layout_get_extents (layout, &logical_rect, NULL);
 
-                  gtk_paint_layout (widget->style,
-                                    ruler->backing_store,
-                                    GTK_WIDGET_STATE (widget),
-                                    FALSE,
-                                    NULL,
-                                    widget,
-                                    "hruler",
-                                    pos + 2, ythickness + PANGO_PIXELS (logical_rect.y - digit_offset),
-                                    layout);
+                  gtk_paint_layout (style,
+                                          cr,
+                                          gtk_widget_get_state (widget),
+                                          FALSE,
+                                          widget,
+                                          "hruler",
+                                          pos + 2, ythickness + PANGO_PIXELS (logical_rect.y - digit_offset),
+                                          layout);
                 }
               else
                 {
@@ -798,16 +839,15 @@ gtk_ruler_real_draw_ticks (GtkRuler *ruler)
                       pango_layout_set_text (layout, unit_str + j, 1);
                       pango_layout_get_extents (layout, NULL, &logical_rect);
 
-                      gtk_paint_layout (widget->style,
-                                        ruler->backing_store,
-                                        GTK_WIDGET_STATE (widget),
-                                        FALSE,
-                                        NULL,
-                                        widget,
-                                        "vruler",
-                                        xthickness + 1,
-                                        pos + digit_height * j + 2 + PANGO_PIXELS (logical_rect.y - digit_offset),
-                                        layout);
+                      gtk_paint_layout (style,
+                                              cr,
+                                              gtk_widget_get_state (widget),
+                                              FALSE,
+                                              widget,
+                                              "vruler",
+                                              xthickness + 1,
+                                              pos + digit_height * j + 2 + PANGO_PIXELS (logical_rect.y - digit_offset),
+                                              layout);
                     }
                 }
 	    }
@@ -815,100 +855,82 @@ gtk_ruler_real_draw_ticks (GtkRuler *ruler)
     }
 
   cairo_fill (cr);
-out:
-  cairo_destroy (cr);
 
+out:
   g_object_unref (layout);
 }
 
 static void
-gtk_ruler_real_draw_pos (GtkRuler *ruler)
+gtk_ruler_real_draw_pos (GtkRuler *ruler,
+                         cairo_t  *cr)
 {
   GtkWidget *widget = GTK_WIDGET (ruler);
-  GtkRulerPrivate *private = GTK_RULER_GET_PRIVATE (ruler);
-  gint x, y;
-  gint width, height;
+  GtkRulerPrivate *priv = ruler->priv;
+  GtkStyle *style;
+  gint x, y, width, height;
   gint bs_width, bs_height;
   gint xthickness;
   gint ythickness;
   gdouble increment;
 
-  if (GTK_WIDGET_DRAWABLE (ruler))
+  style = gtk_widget_get_style (widget);
+  xthickness = style->xthickness;
+  ythickness = style->ythickness;
+  width = gtk_widget_get_allocated_width (widget);
+  height = gtk_widget_get_allocated_height (widget);
+
+  if (priv->orientation == GTK_ORIENTATION_HORIZONTAL)
     {
-      xthickness = widget->style->xthickness;
-      ythickness = widget->style->ythickness;
-      width = widget->allocation.width;
-      height = widget->allocation.height;
+      height -= ythickness * 2;
 
-      if (private->orientation == GTK_ORIENTATION_HORIZONTAL)
+      bs_width = height / 2 + 2;
+      bs_width |= 1;  /* make sure it's odd */
+      bs_height = bs_width / 2 + 1;
+    }
+  else
+    {
+      width -= xthickness * 2;
+
+      bs_height = width / 2 + 2;
+      bs_height |= 1;  /* make sure it's odd */
+      bs_width = bs_height / 2 + 1;
+    }
+
+  if ((bs_width > 0) && (bs_height > 0))
+    {
+      if (priv->orientation == GTK_ORIENTATION_HORIZONTAL)
         {
-          height -= ythickness * 2;
+          increment = (gdouble) width / (priv->upper - priv->lower);
 
-          bs_width = height / 2 + 2;
-          bs_width |= 1;  /* make sure it's odd */
-          bs_height = bs_width / 2 + 1;
+          x = ROUND ((priv->position - priv->lower) * increment) + (xthickness - bs_width) / 2 - 1;
+          y = (height + bs_height) / 2 + ythickness;
         }
       else
         {
-          width -= xthickness * 2;
+          increment = (gdouble) height / (priv->upper - priv->lower);
 
-          bs_height = width / 2 + 2;
-          bs_height |= 1;  /* make sure it's odd */
-          bs_width = bs_height / 2 + 1;
+          x = (width + bs_width) / 2 + xthickness;
+          y = ROUND ((priv->position - priv->lower) * increment) + (ythickness - bs_height) / 2 - 1;
         }
 
-      if ((bs_width > 0) && (bs_height > 0))
-	{
-	  cairo_t *cr = gdk_cairo_create (widget->window);
+      gdk_cairo_set_source_color (cr, &style->fg[gtk_widget_get_state (widget)]);
 
-	  /*  If a backing store exists, restore the ruler  */
-	  if (ruler->backing_store)
-	    gdk_draw_drawable (widget->window,
-			       widget->style->black_gc,
-			       ruler->backing_store,
-			       ruler->xsrc, ruler->ysrc,
-			       ruler->xsrc, ruler->ysrc,
-			       bs_width, bs_height);
+      cairo_move_to (cr, x, y);
 
-          if (private->orientation == GTK_ORIENTATION_HORIZONTAL)
-            {
-              increment = (gdouble) width / (ruler->upper - ruler->lower);
+      if (priv->orientation == GTK_ORIENTATION_HORIZONTAL)
+        {
+          cairo_line_to (cr, x + bs_width / 2.0, y + bs_height);
+          cairo_line_to (cr, x + bs_width,       y);
+        }
+      else
+        {
+          cairo_line_to (cr, x + bs_width, y + bs_height / 2.0);
+          cairo_line_to (cr, x,            y + bs_height);
+        }
 
-              x = ROUND ((ruler->position - ruler->lower) * increment) + (xthickness - bs_width) / 2 - 1;
-              y = (height + bs_height) / 2 + ythickness;
-            }
-          else
-            {
-              increment = (gdouble) height / (ruler->upper - ruler->lower);
+      cairo_fill (cr);
 
-              x = (width + bs_width) / 2 + xthickness;
-              y = ROUND ((ruler->position - ruler->lower) * increment) + (ythickness - bs_height) / 2 - 1;
-            }
-
-	  gdk_cairo_set_source_color (cr, &widget->style->fg[widget->state]);
-
-	  cairo_move_to (cr, x, y);
-
-          if (private->orientation == GTK_ORIENTATION_HORIZONTAL)
-            {
-              cairo_line_to (cr, x + bs_width / 2.0, y + bs_height);
-              cairo_line_to (cr, x + bs_width,       y);
-            }
-          else
-            {
-              cairo_line_to (cr, x + bs_width, y + bs_height / 2.0);
-              cairo_line_to (cr, x,            y + bs_height);
-            }
-
-	  cairo_fill (cr);
-
-	  cairo_destroy (cr);
-
-	  ruler->xsrc = x;
-	  ruler->ysrc = y;
-	}
+      priv->xsrc = x;
+      priv->ysrc = y;
     }
 }
-
-#define __GTK_RULER_C__
-#include "gtkaliasdef.c"
