@@ -75,8 +75,10 @@ struct _GtkRulerClass
 {
   GtkWidgetClass parent_class;
 
-  void (* draw_ticks) (GtkRuler *ruler);
-  void (* draw_pos)   (GtkRuler *ruler);
+  void (* draw_ticks) (GtkRuler *ruler,
+                       cairo_t  *cr);
+  void (* draw_pos)   (GtkRuler *ruler,
+                       cairo_t  *cr);
 
   /* Padding for future expansion */
   void (*_gtk_reserved1) (void);
@@ -113,9 +115,6 @@ void            gtk_ruler_get_range  (GtkRuler       *ruler,
                                       gdouble        *position,
                                       gdouble        *max_size);
 
-void            gtk_ruler_draw_ticks (GtkRuler       *ruler);
-void            gtk_ruler_draw_pos   (GtkRuler       *ruler);
-
 G_END_DECLS
 
 #endif /* __GTK_RULER_H__ */
