@@ -24,7 +24,7 @@
  * GTK+ at ftp://ftp.gtk.org/pub/gtk/.
  */
 
-#if defined(GTK_DISABLE_SINGLE_INCLUDES) && !defined (__GTK_H_INSIDE__) && !defined (GTK_COMPILATION)
+#if !defined (__GTK_H_INSIDE__) && !defined (GTK_COMPILATION)
 #error "Only <gtk/gtk.h> can be included directly."
 #endif
 
@@ -32,7 +32,6 @@
 #define __GTK_SCROLLED_WINDOW_H__
 
 
-#include <gdk/gdk.h>
 #include <gtk/gtkhscrollbar.h>
 #include <gtk/gtkvscrollbar.h>
 #include <gtk/gtkviewport.h>
@@ -49,27 +48,15 @@ G_BEGIN_DECLS
 #define GTK_SCROLLED_WINDOW_GET_CLASS(obj)  (G_TYPE_INSTANCE_GET_CLASS ((obj), GTK_TYPE_SCROLLED_WINDOW, GtkScrolledWindowClass))
 
 
-
-typedef struct _GtkScrolledWindow       GtkScrolledWindow;
-typedef struct _GtkScrolledWindowClass  GtkScrolledWindowClass;
+typedef struct _GtkScrolledWindow              GtkScrolledWindow;
+typedef struct _GtkScrolledWindowPrivate       GtkScrolledWindowPrivate;
+typedef struct _GtkScrolledWindowClass         GtkScrolledWindowClass;
 
 struct _GtkScrolledWindow
 {
   GtkBin container;
 
-  /*< public >*/
-  GtkWidget *hscrollbar;
-  GtkWidget *vscrollbar;
-
-  /*< private >*/
-  guint hscrollbar_policy      : 2;
-  guint vscrollbar_policy      : 2;
-  guint hscrollbar_visible     : 1;
-  guint vscrollbar_visible     : 1;
-  guint window_placement       : 2;
-  guint focus_out              : 1;	/* Flag used by ::move-focus-out implementation */
-
-  guint16 shadow_type;
+  GtkScrolledWindowPrivate *priv;
 };
 
 struct _GtkScrolledWindowClass
