@@ -18,12 +18,29 @@
  * Boston, MA 02111-1307, USA.
  */
 
-#include <config.h>
+#include "config.h"
+#include <string.h>
 #include "gtkcontainer.h"
 #include "gtkintl.h"
 #include "gtkprivate.h"
 #include "gtksizegroup.h"
-#include "gtkalias.h"
+#include "gtkbuildable.h"
+
+
+
+struct _GtkSizeGroupPrivate
+{
+  GtkRequisition  minimum_req;
+  GtkRequisition  natural_req;
+
+  GSList         *widgets;
+
+  guint8          mode;
+
+  guint           have_width    : 1;
+  guint           have_height   : 1;
+  guint           ignore_hidden : 1;
+};
 
 enum {
   PROP_0,
@@ -49,12 +66,29 @@ static void add_widget_to_closure (GtkWidget         *widget,
 				   GSList           **groups,
 				   GSList           **widgets);
 
+/* GtkBuildable */
+static void gtk_size_group_buildable_init (GtkBuildableIface *iface);
+static gboolean gtk_size_group_buildable_custom_tag_start (GtkBuildable  *buildable,
+							   GtkBuilder    *builder,
+							   GObject       *child,
+							   const gchar   *tagname,
+							   GMarkupParser *parser,
+							   gpointer      *data);
+static void gtk_size_group_buildable_custom_finished (GtkBuildable  *buildable,
+						      GtkBuilder    *builder,
+						      GObject       *child,
+						      const gchar   *tagname,
+						      gpointer       user_data);
+
 static GQuark size_groups_quark;
 static const gchar size_groups_tag[] = "gtk-size-groups";
 
 static GQuark visited_quark;
 static const gchar visited_tag[] = "gtk-size-group-visited";
 
+static GQuark bumping_quark;
+static const gchar bumping_tag[] = "gtk-size-group-bumping";
+
 static GSList *
 get_size_groups (GtkWidget *widget)
 {
@@ -86,18 +120,31 @@ is_visited (gpointer object)
   return g_object_get_qdata (object, visited_quark) != NULL;
 }
 
+static void
+mark_bumping (gpointer object, gboolean bumping)
+{
+  g_object_set_qdata (object, bumping_quark, bumping ? "bumping" : NULL);
+}
+
+static gboolean
+is_bumping (gpointer object)
+{
+  return g_object_get_qdata (object, bumping_quark) != NULL;
+}
+
 static void
 add_group_to_closure (GtkSizeGroup    *group,
 		      GtkSizeGroupMode mode,
 		      GSList         **groups,
 		      GSList         **widgets)
 {
+  GtkSizeGroupPrivate *priv = group->priv;
   GSList *tmp_widgets;
   
   *groups = g_slist_prepend (*groups, group);
   mark_visited (group);
 
-  tmp_widgets = group->widgets;
+  tmp_widgets = priv->widgets;
   while (tmp_widgets)
     {
       GtkWidget *tmp_widget = tmp_widgets->data;
@@ -124,8 +171,9 @@ add_widget_to_closure (GtkWidget       *widget,
   while (tmp_groups)
     {
       GtkSizeGroup *tmp_group = tmp_groups->data;
-      
-      if ((tmp_group->mode == GTK_SIZE_GROUP_BOTH || tmp_group->mode == mode) &&
+      GtkSizeGroupPrivate *tmp_priv = tmp_group->priv;
+
+      if ((tmp_priv->mode == GTK_SIZE_GROUP_BOTH || tmp_priv->mode == mode) &&
 	  !is_visited (tmp_group))
 	add_group_to_closure (tmp_group, mode, groups, widgets);
 
@@ -136,12 +184,16 @@ add_widget_to_closure (GtkWidget       *widget,
 static void
 real_queue_resize (GtkWidget *widget)
 {
-  GTK_PRIVATE_SET_FLAG (widget, GTK_ALLOC_NEEDED);
-  GTK_PRIVATE_SET_FLAG (widget, GTK_REQUEST_NEEDED);
-  
-  if (widget->parent)
-    _gtk_container_queue_resize (GTK_CONTAINER (widget->parent));
-  else if (GTK_WIDGET_TOPLEVEL (widget) && GTK_IS_CONTAINER (widget))
+  GtkWidget *parent;
+
+  _gtk_widget_set_alloc_needed (widget, TRUE);
+  _gtk_widget_set_width_request_needed (widget, TRUE);
+  _gtk_widget_set_height_request_needed (widget, TRUE);
+
+  parent = gtk_widget_get_parent (widget);
+  if (parent)
+    _gtk_container_queue_resize (GTK_CONTAINER (parent));
+  else if (gtk_widget_is_toplevel (widget) && GTK_IS_CONTAINER (widget))
     _gtk_container_queue_resize (GTK_CONTAINER (widget));
 }
 
@@ -152,10 +204,11 @@ reset_group_sizes (GSList *groups)
   while (tmp_list)
     {
       GtkSizeGroup *tmp_group = tmp_list->data;
+      GtkSizeGroupPrivate *tmp_priv = tmp_group->priv;
+
+      tmp_priv->have_width = FALSE;
+      tmp_priv->have_height = FALSE;
 
-      tmp_group->have_width = FALSE;
-      tmp_group->have_height = FALSE;
-      
       tmp_list = tmp_list->next;
     }
 }
@@ -176,7 +229,7 @@ queue_resize_on_widget (GtkWidget *widget,
       if (widget == parent && !check_siblings)
 	{
 	  real_queue_resize (widget);
-	  parent = parent->parent;
+          parent = gtk_widget_get_parent (parent);
 	  continue;
 	}
       
@@ -186,7 +239,7 @@ queue_resize_on_widget (GtkWidget *widget,
 	  if (widget == parent)
 	    real_queue_resize (widget);
 
-	  parent = parent->parent;
+          parent = gtk_widget_get_parent (parent);
 	  continue;
 	}
 
@@ -207,6 +260,10 @@ queue_resize_on_widget (GtkWidget *widget,
 	      if (widget == parent)
 		real_queue_resize (parent);
 	    }
+	  else if (tmp_list->data == widget)
+            {
+              g_warning ("A container and its child are part of this SizeGroup");
+            }
 	  else
 	    queue_resize_on_widget (tmp_list->data, FALSE);
 
@@ -233,6 +290,10 @@ queue_resize_on_widget (GtkWidget *widget,
 	      if (widget == parent)
 		real_queue_resize (parent);
 	    }
+	  else if (tmp_list->data == widget)
+            {
+              g_warning ("A container and its child are part of this SizeGroup");
+            }
 	  else
 	    queue_resize_on_widget (tmp_list->data, FALSE);
 
@@ -241,16 +302,18 @@ queue_resize_on_widget (GtkWidget *widget,
       
       g_slist_free (widgets);
       g_slist_free (groups);
-      
-      parent = parent->parent;
+
+      parent = gtk_widget_get_parent (parent);
     }
 }
 
 static void
 queue_resize_on_group (GtkSizeGroup *size_group)
 {
-  if (size_group->widgets)
-    queue_resize_on_widget (size_group->widgets->data, TRUE);
+  GtkSizeGroupPrivate *priv = size_group->priv;
+
+  if (priv->widgets)
+    queue_resize_on_widget (priv->widgets->data, TRUE);
 }
 
 static void
@@ -259,7 +322,8 @@ initialize_size_group_quarks (void)
   if (!size_groups_quark)
     {
       size_groups_quark = g_quark_from_static_string (size_groups_tag);
-      visited_quark = g_quark_from_string (visited_tag);
+      visited_quark = g_quark_from_static_string (visited_tag);
+      bumping_quark = g_quark_from_static_string (bumping_tag);
     }
 }
 
@@ -296,21 +360,39 @@ gtk_size_group_class_init (GtkSizeGroupClass *klass)
 							    "when determining the size of the group"),
 							 FALSE,
 							 GTK_PARAM_READWRITE));
-  
+
+  g_type_class_add_private (klass, sizeof (GtkSizeGroupPrivate));
+
   initialize_size_group_quarks ();
 }
 
 static void
 gtk_size_group_init (GtkSizeGroup *size_group)
 {
-  size_group->widgets = NULL;
-  size_group->mode = GTK_SIZE_GROUP_HORIZONTAL;
-  size_group->have_width = 0;
-  size_group->have_height = 0;
-  size_group->ignore_hidden = 0;
+  GtkSizeGroupPrivate *priv;
+
+  size_group->priv = G_TYPE_INSTANCE_GET_PRIVATE (size_group,
+                                                  GTK_TYPE_SIZE_GROUP,
+                                                  GtkSizeGroupPrivate);
+  priv = size_group->priv;
+
+  priv->widgets = NULL;
+  priv->mode = GTK_SIZE_GROUP_HORIZONTAL;
+  priv->have_width = 0;
+  priv->have_height = 0;
+  priv->ignore_hidden = 0;
 }
 
-G_DEFINE_TYPE (GtkSizeGroup, gtk_size_group, G_TYPE_OBJECT)
+static void
+gtk_size_group_buildable_init (GtkBuildableIface *iface)
+{
+  iface->custom_tag_start = gtk_size_group_buildable_custom_tag_start;
+  iface->custom_finished = gtk_size_group_buildable_custom_finished;
+}
+
+G_DEFINE_TYPE_WITH_CODE (GtkSizeGroup, gtk_size_group, G_TYPE_OBJECT,
+			 G_IMPLEMENT_INTERFACE (GTK_TYPE_BUILDABLE,
+						gtk_size_group_buildable_init))
 
 static void
 gtk_size_group_set_property (GObject      *object,
@@ -341,14 +423,15 @@ gtk_size_group_get_property (GObject      *object,
 			     GParamSpec   *pspec)
 {
   GtkSizeGroup *size_group = GTK_SIZE_GROUP (object);
+  GtkSizeGroupPrivate *priv = size_group->priv;
 
   switch (prop_id)
     {
     case PROP_MODE:
-      g_value_set_enum (value, size_group->mode);
+      g_value_set_enum (value, priv->mode);
       break;
     case PROP_IGNORE_HIDDEN:
-      g_value_set_boolean (value, size_group->ignore_hidden);
+      g_value_set_boolean (value, priv->ignore_hidden);
       break;
     default:
       G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
@@ -368,8 +451,9 @@ GtkSizeGroup *
 gtk_size_group_new (GtkSizeGroupMode mode)
 {
   GtkSizeGroup *size_group = g_object_new (GTK_TYPE_SIZE_GROUP, NULL);
+  GtkSizeGroupPrivate *priv = size_group->priv;
 
-  size_group->mode = mode;
+  priv->mode = mode;
 
   return size_group;
 }
@@ -390,14 +474,18 @@ void
 gtk_size_group_set_mode (GtkSizeGroup     *size_group,
 			 GtkSizeGroupMode  mode)
 {
+  GtkSizeGroupPrivate *priv;
+
   g_return_if_fail (GTK_IS_SIZE_GROUP (size_group));
 
-  if (size_group->mode != mode)
+  priv = size_group->priv;
+
+  if (priv->mode != mode)
     {
-      if (size_group->mode != GTK_SIZE_GROUP_NONE)
+      if (priv->mode != GTK_SIZE_GROUP_NONE)
 	queue_resize_on_group (size_group);
-      size_group->mode = mode;
-      if (size_group->mode != GTK_SIZE_GROUP_NONE)
+      priv->mode = mode;
+      if (priv->mode != GTK_SIZE_GROUP_NONE)
 	queue_resize_on_group (size_group);
 
       g_object_notify (G_OBJECT (size_group), "mode");
@@ -417,7 +505,7 @@ gtk_size_group_get_mode (GtkSizeGroup *size_group)
 {
   g_return_val_if_fail (GTK_IS_SIZE_GROUP (size_group), GTK_SIZE_GROUP_BOTH);
 
-  return size_group->mode;
+  return size_group->priv->mode;
 }
 
 /**
@@ -435,13 +523,17 @@ void
 gtk_size_group_set_ignore_hidden (GtkSizeGroup *size_group,
 				  gboolean      ignore_hidden)
 {
+  GtkSizeGroupPrivate *priv;
+
   g_return_if_fail (GTK_IS_SIZE_GROUP (size_group));
-  
+
+  priv = size_group->priv;
+
   ignore_hidden = ignore_hidden != FALSE;
 
-  if (size_group->ignore_hidden != ignore_hidden)
+  if (priv->ignore_hidden != ignore_hidden)
     {
-      size_group->ignore_hidden = ignore_hidden;
+      priv->ignore_hidden = ignore_hidden;
 
       g_object_notify (G_OBJECT (size_group), "ignore-hidden");
     }
@@ -462,7 +554,7 @@ gtk_size_group_get_ignore_hidden (GtkSizeGroup *size_group)
 {
   g_return_val_if_fail (GTK_IS_SIZE_GROUP (size_group), FALSE);
 
-  return size_group->ignore_hidden;
+  return size_group->priv->ignore_hidden;
 }
 
 static void
@@ -482,16 +574,22 @@ gtk_size_group_widget_destroyed (GtkWidget    *widget,
  * and the requisition of the other widgets in the size group.
  * Whether this applies horizontally, vertically, or in both directions
  * depends on the mode of the size group. See gtk_size_group_set_mode().
- **/
+ *
+ * When the widget is destroyed or no longer referenced elsewhere, it will 
+ * be removed from the size group.
+ */
 void
 gtk_size_group_add_widget (GtkSizeGroup     *size_group,
 			   GtkWidget        *widget)
 {
+  GtkSizeGroupPrivate *priv;
   GSList *groups;
   
   g_return_if_fail (GTK_IS_SIZE_GROUP (size_group));
   g_return_if_fail (GTK_IS_WIDGET (widget));
-  
+
+  priv = size_group->priv;
+
   groups = get_size_groups (widget);
 
   if (!g_slist_find (groups, size_group))
@@ -499,7 +597,7 @@ gtk_size_group_add_widget (GtkSizeGroup     *size_group,
       groups = g_slist_prepend (groups, size_group);
       set_size_groups (widget, groups);
 
-      size_group->widgets = g_slist_prepend (size_group->widgets, widget);
+      priv->widgets = g_slist_prepend (priv->widgets, widget);
 
       g_signal_connect (widget, "destroy",
 			G_CALLBACK (gtk_size_group_widget_destroyed),
@@ -513,7 +611,7 @@ gtk_size_group_add_widget (GtkSizeGroup     *size_group,
 
 /**
  * gtk_size_group_remove_widget:
- * @size_group: a #GtkSizeGrup
+ * @size_group: a #GtkSizeGroup
  * @widget: the #GtkWidget to remove
  * 
  * Removes a widget from a #GtkSizeGroup.
@@ -522,11 +620,15 @@ void
 gtk_size_group_remove_widget (GtkSizeGroup *size_group,
 			      GtkWidget    *widget)
 {
+  GtkSizeGroupPrivate *priv;
   GSList *groups;
   
   g_return_if_fail (GTK_IS_SIZE_GROUP (size_group));
   g_return_if_fail (GTK_IS_WIDGET (widget));
-  g_return_if_fail (g_slist_find (size_group->widgets, widget));
+
+  priv = size_group->priv;
+
+  g_return_if_fail (g_slist_find (priv->widgets, widget));
 
   g_signal_handlers_disconnect_by_func (widget,
 					gtk_size_group_widget_destroyed,
@@ -536,7 +638,7 @@ gtk_size_group_remove_widget (GtkSizeGroup *size_group,
   groups = g_slist_remove (groups, size_group);
   set_size_groups (widget, groups);
 
-  size_group->widgets = g_slist_remove (size_group->widgets, widget);
+  priv->widgets = g_slist_remove (priv->widgets, widget);
   queue_resize_on_group (size_group);
   gtk_widget_queue_resize (widget);
 
@@ -545,73 +647,31 @@ gtk_size_group_remove_widget (GtkSizeGroup *size_group,
 
 /**
  * gtk_size_group_get_widgets:
- * @size_group: a #GtkSizeGrup
+ * @size_group: a #GtkSizeGroup
  * 
  * Returns the list of widgets associated with @size_group.
  *
- * Return value: a #GSList of widgets. The list is owned by GTK+ 
- *   and should not be modified.
+ * Return value:  (element-type GtkWidget) (transfer none): a #GSList of
+ *   widgets. The list is owned by GTK+ and should not be modified.
  *
  * Since: 2.10
  **/
 GSList *
 gtk_size_group_get_widgets (GtkSizeGroup *size_group)
 {
-  return size_group->widgets;
-}
-
-static gint
-get_base_dimension (GtkWidget        *widget,
-		    GtkSizeGroupMode  mode)
-{
-  GtkWidgetAuxInfo *aux_info = _gtk_widget_get_aux_info (widget, FALSE);
-
-  if (mode == GTK_SIZE_GROUP_HORIZONTAL)
-    {
-      if (aux_info && aux_info->width > 0)
-	return aux_info->width;
-      else
-	return widget->requisition.width;
-    }
-  else
-    {
-      if (aux_info && aux_info->height > 0)
-	return aux_info->height;
-      else
-	return widget->requisition.height;
-    }
+  return size_group->priv->widgets;
 }
 
 static void
-do_size_request (GtkWidget *widget)
-{
-  if (GTK_WIDGET_REQUEST_NEEDED (widget))
-    {
-      gtk_widget_ensure_style (widget);      
-      GTK_PRIVATE_UNSET_FLAG (widget, GTK_REQUEST_NEEDED);
-      g_signal_emit_by_name (widget,
-			     "size_request",
-			     &widget->requisition);
-    }
-}
-
-static gint
-compute_base_dimension (GtkWidget        *widget,
-			GtkSizeGroupMode  mode)
-{
-  do_size_request (widget);
-
-  return get_base_dimension (widget, mode);
-}
-
-static gint
 compute_dimension (GtkWidget        *widget,
-		   GtkSizeGroupMode  mode)
+		   GtkSizeGroupMode  mode,
+		   gint             *minimum, /* in-out */
+		   gint             *natural) /* in-out */
 {
   GSList *widgets = NULL;
   GSList *groups = NULL;
   GSList *tmp_list;
-  gint result = 0;
+  gint    min_result = 0, nat_result = 0;
 
   add_widget_to_closure (widget, mode, &groups, &widgets);
 
@@ -622,29 +682,49 @@ compute_dimension (GtkWidget        *widget,
   
   if (!groups)
     {
-      result = compute_base_dimension (widget, mode);
+      min_result = *minimum;
+      nat_result = *natural;
     }
   else
     {
       GtkSizeGroup *group = groups->data;
+      GtkSizeGroupPrivate *priv = group->priv;
 
-      if (mode == GTK_SIZE_GROUP_HORIZONTAL && group->have_width)
-	result = group->requisition.width;
-      else if (mode == GTK_SIZE_GROUP_VERTICAL && group->have_height)
-	result = group->requisition.height;
+      if (mode == GTK_SIZE_GROUP_HORIZONTAL && priv->have_width)
+	{
+	  min_result = priv->minimum_req.width;
+	  nat_result = priv->natural_req.width;
+	}
+      else if (mode == GTK_SIZE_GROUP_VERTICAL && priv->have_height)
+	{
+	  min_result = priv->minimum_req.height;
+	  nat_result = priv->natural_req.height;
+	}
       else
 	{
 	  tmp_list = widgets;
 	  while (tmp_list)
 	    {
 	      GtkWidget *tmp_widget = tmp_list->data;
+	      gint min_dimension, nat_dimension;
 
-	      gint dimension = compute_base_dimension (tmp_widget, mode);
-
-	      if (GTK_WIDGET_MAPPED (tmp_widget) || !group->ignore_hidden)
+	      if (tmp_widget == widget)
 		{
-		  if (dimension > result)
-		    result = dimension;
+		  min_dimension = *minimum;
+		  nat_dimension = *natural;
+		}
+	      else
+		{
+		  if (mode == GTK_SIZE_GROUP_HORIZONTAL)
+		    gtk_widget_get_preferred_width (tmp_widget, &min_dimension, &nat_dimension);
+		  else
+		    gtk_widget_get_preferred_height (tmp_widget, &min_dimension, &nat_dimension);
+		}
+
+	      if (gtk_widget_get_mapped (tmp_widget) || !priv->ignore_hidden)
+		{
+		  min_result = MAX (min_result, min_dimension);
+		  nat_result = MAX (nat_result, nat_dimension);
 		}
 
 	      tmp_list = tmp_list->next;
@@ -654,16 +734,20 @@ compute_dimension (GtkWidget        *widget,
 	  while (tmp_list)
 	    {
 	      GtkSizeGroup *tmp_group = tmp_list->data;
+              GtkSizeGroupPrivate *tmp_priv = tmp_group->priv;
 
 	      if (mode == GTK_SIZE_GROUP_HORIZONTAL)
 		{
-		  tmp_group->have_width = TRUE;
-		  tmp_group->requisition.width = result;
+		  tmp_priv->have_width = TRUE;
+		  tmp_priv->minimum_req.width = min_result;
+		  tmp_priv->natural_req.width = nat_result;
 		}
 	      else
 		{
-		  tmp_group->have_height = TRUE;
-		  tmp_group->requisition.height = result;
+		  tmp_priv->have_height = TRUE;
+
+		  tmp_priv->minimum_req.height = min_result;
+		  tmp_priv->natural_req.height = nat_result;
 		}
 	      
 	      tmp_list = tmp_list->next;
@@ -676,125 +760,44 @@ compute_dimension (GtkWidget        *widget,
   g_slist_free (widgets);
   g_slist_free (groups);
 
-  return result;
-}
-
-static gint
-get_dimension (GtkWidget        *widget,
-	       GtkSizeGroupMode  mode)
-{
-  GSList *widgets = NULL;
-  GSList *groups = NULL;
-  gint result = 0;
-
-  add_widget_to_closure (widget, mode, &groups, &widgets);
-
-  g_slist_foreach (widgets, (GFunc)mark_unvisited, NULL);
-  g_slist_foreach (groups, (GFunc)mark_unvisited, NULL);  
-
-  if (!groups)
-    {
-      result = get_base_dimension (widget, mode);
-    }
-  else
-    {
-      GtkSizeGroup *group = groups->data;
-
-      if (mode == GTK_SIZE_GROUP_HORIZONTAL && group->have_width)
-	result = group->requisition.width;
-      else if (mode == GTK_SIZE_GROUP_VERTICAL && group->have_height)
-	result = group->requisition.height;
-    }
-
-  g_slist_free (widgets);
-  g_slist_free (groups);
-
-  return result;
-}
-
-static void
-get_fast_child_requisition (GtkWidget      *widget,
-			    GtkRequisition *requisition)
-{
-  GtkWidgetAuxInfo *aux_info = _gtk_widget_get_aux_info (widget, FALSE);
-  
-  *requisition = widget->requisition;
-  
-  if (aux_info)
-    {
-      if (aux_info->width > 0)
-	requisition->width = aux_info->width;
-      if (aux_info && aux_info->height > 0)
-	requisition->height = aux_info->height;
-    }
+  *minimum = min_result;
+  *natural = nat_result;
 }
 
 /**
- * _gtk_size_group_get_child_requisition:
+ * _gtk_size_group_bump_requisition:
  * @widget: a #GtkWidget
- * @requisition: location to store computed requisition.
- * 
- * Retrieve the "child requisition" of the widget, taking account grouping
- * of the widget's requisition with other widgets.
- **/
+ * @mode: either %GTK_SIZE_GROUP_HORIZONTAL or %GTK_SIZE_GROUP_VERTICAL, depending
+ *        on the dimension in which to bump the size.
+ * @minimum: a pointer to the widget's minimum size
+ * @natural: a pointer to the widget's natural size
+ *
+ * Refreshes the sizegroup while returning the groups requested
+ * value in the dimension @mode.
+ *
+ * This function is used both to update sizegroup minimum and natural size 
+ * information and widget minimum and natural sizes in multiple passes from 
+ * the size request apis.
+ */
 void
-_gtk_size_group_get_child_requisition (GtkWidget      *widget,
-				       GtkRequisition *requisition)
+_gtk_size_group_bump_requisition (GtkWidget        *widget,
+				  GtkSizeGroupMode  mode,
+				  gint             *minimum,
+				  gint             *natural)
 {
-  initialize_size_group_quarks ();
-
-  if (requisition)
+  if (!is_bumping (widget))
     {
+      /* Avoid recursion here */
+      mark_bumping (widget, TRUE);
+
       if (get_size_groups (widget))
-	{
-	  requisition->width = get_dimension (widget, GTK_SIZE_GROUP_HORIZONTAL);
-	  requisition->height = get_dimension (widget, GTK_SIZE_GROUP_VERTICAL);
+	compute_dimension (widget, mode, minimum, natural);
 
-	  /* Only do the full computation if we actually have size groups */
-	}
-      else
-	get_fast_child_requisition (widget, requisition);
+      mark_bumping (widget, FALSE);
     }
 }
 
-/**
- * _gtk_size_group_compute_requisition:
- * @widget: a #GtkWidget
- * @requisition: location to store computed requisition.
- * 
- * Compute the requisition of a widget taking into account grouping of
- * the widget's requisition with other widgets.
- **/
-void
-_gtk_size_group_compute_requisition (GtkWidget      *widget,
-				     GtkRequisition *requisition)
-{
-  gint width;
-  gint height;
 
-  initialize_size_group_quarks ();
-
-  if (get_size_groups (widget))
-    {
-      /* Only do the full computation if we actually have size groups */
-      
-      width = compute_dimension (widget, GTK_SIZE_GROUP_HORIZONTAL);
-      height = compute_dimension (widget, GTK_SIZE_GROUP_VERTICAL);
-
-      if (requisition)
-	{
-	  requisition->width = width;
-	  requisition->height = height;
-	}
-    }
-  else
-    {
-      do_size_request (widget);
-      
-      if (requisition)
-	get_fast_child_requisition (widget, requisition);
-    }
-}
 
 /**
  * _gtk_size_group_queue_resize:
@@ -810,5 +813,97 @@ _gtk_size_group_queue_resize (GtkWidget *widget)
   queue_resize_on_widget (widget, TRUE);
 }
 
-#define __GTK_SIZE_GROUP_C__
-#include "gtkaliasdef.c"
+typedef struct {
+  GObject *object;
+  GSList *items;
+} GSListSubParserData;
+
+static void
+size_group_start_element (GMarkupParseContext *context,
+			  const gchar         *element_name,
+			  const gchar        **names,
+			  const gchar        **values,
+			  gpointer            user_data,
+			  GError            **error)
+{
+  guint i;
+  GSListSubParserData *data = (GSListSubParserData*)user_data;
+
+  if (strcmp (element_name, "widget") == 0)
+    for (i = 0; names[i]; i++)
+      if (strcmp (names[i], "name") == 0)
+	data->items = g_slist_prepend (data->items, g_strdup (values[i]));
+  else if (strcmp (element_name, "widgets") == 0)
+    return;
+  else
+    g_warning ("Unsupported type tag for GtkSizeGroup: %s\n",
+	       element_name);
+
+}
+
+static const GMarkupParser size_group_parser =
+  {
+    size_group_start_element
+  };
+
+static gboolean
+gtk_size_group_buildable_custom_tag_start (GtkBuildable  *buildable,
+					   GtkBuilder    *builder,
+					   GObject       *child,
+					   const gchar   *tagname,
+					   GMarkupParser *parser,
+					   gpointer      *data)
+{
+  GSListSubParserData *parser_data;
+
+  if (child)
+    return FALSE;
+
+  if (strcmp (tagname, "widgets") == 0)
+    {
+      parser_data = g_slice_new0 (GSListSubParserData);
+      parser_data->items = NULL;
+      parser_data->object = G_OBJECT (buildable);
+
+      *parser = size_group_parser;
+      *data = parser_data;
+      return TRUE;
+    }
+
+  return FALSE;
+}
+
+static void
+gtk_size_group_buildable_custom_finished (GtkBuildable  *buildable,
+					  GtkBuilder    *builder,
+					  GObject       *child,
+					  const gchar   *tagname,
+					  gpointer       user_data)
+{
+  GSList *l;
+  GSListSubParserData *data;
+  GObject *object;
+
+  if (strcmp (tagname, "widgets"))
+    return;
+  
+  data = (GSListSubParserData*)user_data;
+  data->items = g_slist_reverse (data->items);
+
+  for (l = data->items; l; l = l->next)
+    {
+      object = gtk_builder_get_object (builder, l->data);
+      if (!object)
+	{
+	  g_warning ("Unknown object %s specified in sizegroup %s",
+		     (const gchar*)l->data,
+		     gtk_buildable_get_name (GTK_BUILDABLE (data->object)));
+	  continue;
+	}
+      gtk_size_group_add_widget (GTK_SIZE_GROUP (data->object),
+				 GTK_WIDGET (object));
+      g_free (l->data);
+    }
+  g_slist_free (data->items);
+  g_slice_free (GSListSubParserData, data);
+}
