@@ -24,19 +24,21 @@
  * GTK+ at ftp://ftp.gtk.org/pub/gtk/.
  */
 
-#ifndef GTK_TEXT_ITER_H
-#define GTK_TEXT_ITER_H
+#if !defined (__GTK_H_INSIDE__) && !defined (GTK_COMPILATION)
+#error "Only <gtk/gtk.h> can be included directly."
+#endif
+
+#ifndef __GTK_TEXT_ITER_H__
+#define __GTK_TEXT_ITER_H__
 
 #include <gtk/gtktexttag.h>
 #include <gtk/gtktextchild.h>
 
-#ifdef __cplusplus
-extern "C" {
-#endif /* __cplusplus */
+G_BEGIN_DECLS
 
 typedef enum {
-  GTK_TEXT_SEARCH_VISIBLE_ONLY,
-  GTK_TEXT_SEARCH_TEXT_ONLY
+  GTK_TEXT_SEARCH_VISIBLE_ONLY = 1 << 0,
+  GTK_TEXT_SEARCH_TEXT_ONLY    = 1 << 1
   /* Possible future plans: SEARCH_CASE_INSENSITIVE, SEARCH_REGEXP */
 } GtkTextSearchFlags;
 
@@ -48,6 +50,8 @@ typedef enum {
 
 typedef struct _GtkTextBuffer GtkTextBuffer;
 
+#define GTK_TYPE_TEXT_ITER     (gtk_text_iter_get_type ())
+
 struct _GtkTextIter {
   /* GtkTextIter is an opaque datatype; ignore all these fields.
    * Initialize the iter with gtk_text_buffer_get_iter_*
@@ -83,6 +87,8 @@ GtkTextBuffer *gtk_text_iter_get_buffer (const GtkTextIter *iter);
 GtkTextIter *gtk_text_iter_copy     (const GtkTextIter *iter);
 void         gtk_text_iter_free     (GtkTextIter       *iter);
 
+GType        gtk_text_iter_get_type (void) G_GNUC_CONST;
+
 /*
  * Convert to different kinds of index
  */
@@ -186,6 +192,20 @@ gboolean gtk_text_iter_forward_word_ends    (GtkTextIter *iter,
                                              gint         count);
 gboolean gtk_text_iter_backward_word_starts (GtkTextIter *iter,
                                              gint         count);
+                                             
+gboolean gtk_text_iter_forward_visible_line   (GtkTextIter *iter);
+gboolean gtk_text_iter_backward_visible_line  (GtkTextIter *iter);
+gboolean gtk_text_iter_forward_visible_lines  (GtkTextIter *iter,
+                                               gint         count);
+gboolean gtk_text_iter_backward_visible_lines (GtkTextIter *iter,
+                                               gint         count);
+
+gboolean gtk_text_iter_forward_visible_word_end     (GtkTextIter *iter);
+gboolean gtk_text_iter_backward_visible_word_start  (GtkTextIter *iter);
+gboolean gtk_text_iter_forward_visible_word_ends    (GtkTextIter *iter,
+                                             gint         count);
+gboolean gtk_text_iter_backward_visible_word_starts (GtkTextIter *iter,
+                                             gint         count);
 
 gboolean gtk_text_iter_forward_sentence_end     (GtkTextIter *iter);
 gboolean gtk_text_iter_backward_sentence_start  (GtkTextIter *iter);
@@ -205,6 +225,13 @@ gboolean gtk_text_iter_forward_cursor_positions  (GtkTextIter *iter,
 gboolean gtk_text_iter_backward_cursor_positions (GtkTextIter *iter,
                                                   gint         count);
 
+gboolean gtk_text_iter_forward_visible_cursor_position   (GtkTextIter *iter);
+gboolean gtk_text_iter_backward_visible_cursor_position  (GtkTextIter *iter);
+gboolean gtk_text_iter_forward_visible_cursor_positions  (GtkTextIter *iter,
+                                                          gint         count);
+gboolean gtk_text_iter_backward_visible_cursor_positions (GtkTextIter *iter,
+                                                          gint         count);
+
 
 void     gtk_text_iter_set_offset         (GtkTextIter *iter,
                                            gint         char_offset);
@@ -273,9 +300,7 @@ gboolean gtk_text_iter_in_range        (const GtkTextIter *iter,
 void     gtk_text_iter_order           (GtkTextIter *first,
                                         GtkTextIter *second);
 
-#ifdef __cplusplus
-}
-#endif /* __cplusplus */
+G_END_DECLS
 
 #endif
 
