@@ -56,15 +56,15 @@ typedef enum
   GTK_TOOLBAR_SPACE_LINE
 } GtkToolbarSpaceStyle;
 
-typedef struct _GtkToolbar           GtkToolbar;
-typedef struct _GtkToolbarPriv       GtkToolbarPriv;
-typedef struct _GtkToolbarClass      GtkToolbarClass;
+typedef struct _GtkToolbar              GtkToolbar;
+typedef struct _GtkToolbarPrivate       GtkToolbarPrivate;
+typedef struct _GtkToolbarClass         GtkToolbarClass;
 
 struct _GtkToolbar
 {
   GtkContainer container;
 
-  GtkToolbarPriv *priv;
+  GtkToolbarPrivate *priv;
 };
 
 struct _GtkToolbarClass
@@ -127,8 +127,7 @@ void            gtk_toolbar_set_drop_highlight_item (GtkToolbar      *toolbar,
 gchar *         _gtk_toolbar_elide_underscores      (const gchar         *original);
 void            _gtk_toolbar_paint_space_line       (GtkWidget           *widget,
 						     GtkToolbar          *toolbar,
-						     const GdkRectangle  *area,
-						     const GtkAllocation *allocation);
+                                                     cairo_t             *cr);
 gint            _gtk_toolbar_get_default_space_size (void);
 
 
