@@ -260,36 +260,36 @@ gtk_tool_item_group_tool_shell_init (GtkToolShellIface *iface)
 }
 
 static gboolean
-gtk_tool_item_group_header_expose_event_cb (GtkWidget      *widget,
-                                            GdkEventExpose *event,
-                                            gpointer        data)
+gtk_tool_item_group_header_draw_cb (GtkWidget *widget,
+                                    cairo_t   *cr,
+                                    gpointer   data)
 {
-  GtkAllocation allocation;
   GtkToolItemGroup *group = GTK_TOOL_ITEM_GROUP (data);
   GtkToolItemGroupPrivate* priv = group->priv;
   GtkExpanderStyle expander_style;
   GtkOrientation orientation;
-  gint x, y;
+  gint x, y, width, height;
   GtkTextDirection direction;
 
   orientation = gtk_tool_shell_get_orientation (GTK_TOOL_SHELL (group));
   expander_style = priv->expander_style;
   direction = gtk_widget_get_direction (widget);
+  width = gtk_widget_get_allocated_width (widget);
+  height = gtk_widget_get_allocated_height (widget);
 
-  gtk_widget_get_allocation (widget, &allocation);
   if (GTK_ORIENTATION_VERTICAL == orientation)
     {
       if (GTK_TEXT_DIR_RTL == direction)
-        x = allocation.x + allocation.width - priv->expander_size / 2;
+        x = width - priv->expander_size / 2;
       else
-        x = allocation.x + priv->expander_size / 2;
+        x = priv->expander_size / 2;
 
-      y = allocation.y + allocation.height / 2;
+      y = height / 2;
     }
   else
     {
-      x = allocation.x + allocation.width / 2;
-      y = allocation.y + priv->expander_size / 2;
+      x = width / 2;
+      y = priv->expander_size / 2;
 
       /* Unfortunatly gtk_paint_expander() doesn't support rotated drawing
        * modes. Luckily the following shady arithmetics produce the desired
@@ -298,9 +298,9 @@ gtk_tool_item_group_header_expose_event_cb (GtkWidget      *widget,
     }
 
   gtk_paint_expander (gtk_widget_get_style (widget),
-                      gtk_widget_get_window (widget),
+                      cr,
                       gtk_widget_get_state (priv->header),
-                      &event->area, GTK_WIDGET (group),
+                      GTK_WIDGET (group),
                       "tool-palette-header", x, y,
                       expander_style);
 
@@ -409,8 +409,8 @@ gtk_tool_item_group_init (GtkToolItemGroup *group)
 
   gtk_tool_item_group_header_adjust_style (group);
 
-  g_signal_connect_after (alignment, "expose-event",
-                          G_CALLBACK (gtk_tool_item_group_header_expose_event_cb),
+  g_signal_connect_after (alignment, "draw",
+                          G_CALLBACK (gtk_tool_item_group_header_draw_cb),
                           group);
   g_signal_connect_after (alignment, "size-request",
                           G_CALLBACK (gtk_tool_item_group_header_size_request_cb),
@@ -554,7 +554,8 @@ gtk_tool_item_group_size_request (GtkWidget      *widget,
 
   if (priv->children && gtk_tool_item_group_get_label_widget (group))
     {
-      gtk_widget_size_request (priv->header, requisition);
+      gtk_widget_get_preferred_size (priv->header,
+                                     requisition, NULL);
       gtk_widget_show (priv->header);
     }
   else
@@ -687,7 +688,8 @@ gtk_tool_item_group_real_size_query (GtkWidget      *widget,
                   GtkRequisition req = {0, 0};
                   guint width;
 
-                  gtk_widget_size_request (GTK_WIDGET (child->item), &req);
+                  gtk_widget_get_preferred_size (GTK_WIDGET (child->item),
+                                                 &req, NULL);
 
                   width = udiv (req.width, item_size.width);
                   col += width;
@@ -745,7 +747,8 @@ gtk_tool_item_group_real_size_query (GtkWidget      *widget,
                   GtkRequisition req = {0, 0};
                   guint width;
 
-                  gtk_widget_size_request (GTK_WIDGET (child->item), &req);
+                  gtk_widget_get_preferred_size (GTK_WIDGET (child->item),
+                                                 &req, NULL);
 
                   width = udiv (req.width, item_size.width);
 
@@ -800,7 +803,8 @@ gtk_tool_item_group_real_size_query (GtkWidget      *widget,
                       GtkRequisition req = {0, 0};
                       guint width;
 
-                      gtk_widget_size_request (GTK_WIDGET (child->item), &req);
+                      gtk_widget_get_preferred_size (GTK_WIDGET (child->item),
+                                                     &req, NULL);
 
                       width = udiv (req.width, item_size.width);
                       col += width;
@@ -832,7 +836,8 @@ gtk_tool_item_group_real_size_query (GtkWidget      *widget,
     {
       GtkRequisition child_requisition;
 
-      gtk_widget_size_request (priv->header, &child_requisition);
+      gtk_widget_get_preferred_size (priv->header,
+                                     &child_requisition, NULL);
 
       if (GTK_ORIENTATION_VERTICAL == orientation)
         inquery->height += child_requisition.height;
@@ -882,7 +887,8 @@ gtk_tool_item_group_real_size_allocate (GtkWidget     *widget,
   /* place the header widget */
   if (gtk_widget_get_visible (priv->header))
     {
-      gtk_widget_size_request (priv->header, &child_requisition);
+      gtk_widget_get_preferred_size (priv->header,
+                                     &child_requisition, NULL);
 
       if (GTK_ORIENTATION_VERTICAL == orientation)
         {
@@ -966,7 +972,8 @@ gtk_tool_item_group_real_size_allocate (GtkWidget     *widget,
 
           if (!child->homogeneous)
             {
-              gtk_widget_size_request (GTK_WIDGET (child->item), &child_requisition);
+              gtk_widget_get_preferred_size (GTK_WIDGET (child->item),
+                                             &child_requisition, NULL);
               child_requisition.width = MIN (child_requisition.width, item_area.width);
             }
 
@@ -1191,18 +1198,17 @@ gtk_tool_item_group_realize (GtkWidget *widget)
   attributes.height = allocation.height - border_width * 2;
   attributes.wclass = GDK_INPUT_OUTPUT;
   attributes.visual = gtk_widget_get_visual (widget);
-  attributes.colormap = gtk_widget_get_colormap (widget);
   attributes.event_mask = gtk_widget_get_events (widget)
                          | GDK_VISIBILITY_NOTIFY_MASK | GDK_EXPOSURE_MASK
                          | GDK_BUTTON_PRESS_MASK | GDK_BUTTON_RELEASE_MASK
                          | GDK_BUTTON_MOTION_MASK;
-  attributes_mask = GDK_WA_X | GDK_WA_Y | GDK_WA_VISUAL | GDK_WA_COLORMAP;
+  attributes_mask = GDK_WA_X | GDK_WA_Y | GDK_WA_VISUAL;
 
   window = gdk_window_new (gtk_widget_get_parent_window (widget),
                            &attributes, attributes_mask);
   gtk_widget_set_window (widget, window);
 
-  display = gdk_drawable_get_display (window);
+  display = gdk_window_get_display (window);
 
   if (gdk_display_supports_composite (display))
     gdk_window_set_composited (window, TRUE);
@@ -1987,7 +1993,7 @@ gtk_tool_item_group_get_label (GtkToolItemGroup *group)
  * Gets the label widget of @group.
  * See gtk_tool_item_group_set_label_widget().
  *
- * Returns: the label widget of @group
+ * Returns: (transfer none): the label widget of @group
  *
  * Since: 2.20
  */
@@ -2192,7 +2198,7 @@ gtk_tool_item_group_get_n_items (GtkToolItemGroup *group)
  *
  * Gets the tool item at @index in group.
  *
- * Returns: the #GtkToolItem at index
+ * Returns: (transfer none): the #GtkToolItem at index
  *
  * Since: 2.20
  */
@@ -2217,7 +2223,7 @@ gtk_tool_item_group_get_nth_item (GtkToolItemGroup *group,
  *
  * Gets the tool item at position (x, y).
  *
- * Returns: the #GtkToolItem at position (x, y)
+ * Returns: (transfer none): the #GtkToolItem at position (x, y)
  *
  * Since: 2.20
  */
@@ -2297,7 +2303,8 @@ _gtk_tool_item_group_item_size_request (GtkToolItemGroup *group,
       if (!child->homogeneous && child->expand)
           new_row = TRUE;
 
-      gtk_widget_size_request (GTK_WIDGET (child->item), &child_requisition);
+      gtk_widget_get_preferred_size (GTK_WIDGET (child->item),
+                                     &child_requisition, NULL);
 
       if (!homogeneous_only || child->homogeneous)
         item_size->width = MAX (item_size->width, child_requisition.width);
@@ -2318,7 +2325,7 @@ _gtk_tool_item_group_paint (GtkToolItemGroup *group,
 
   gtk_widget_get_allocation (widget, &allocation);
 
-  gdk_cairo_set_source_pixmap (cr, gtk_widget_get_window (widget),
+  gdk_cairo_set_source_window (cr, gtk_widget_get_window (widget),
                                allocation.x,
                                allocation.y);
 
@@ -2383,7 +2390,8 @@ _gtk_tool_item_group_get_size_for_limit (GtkToolItemGroup *group,
   GtkRequisition requisition;
   GtkToolItemGroupPrivate* priv = group->priv;
 
-  gtk_widget_size_request (GTK_WIDGET (group), &requisition);
+  gtk_widget_get_preferred_size (GTK_WIDGET (group),
+                                 &requisition, NULL);
 
   if (!priv->collapsed || priv->animation_timeout)
     {
