@@ -17,7 +17,7 @@
  * Boston, MA 02111-1307, USA.
  */
 
-#if defined(GTK_DISABLE_SINGLE_INCLUDES) && !defined (__GTK_H_INSIDE__) && !defined (GTK_COMPILATION)
+#if !defined (__GTK_H_INSIDE__) && !defined (GTK_COMPILATION)
 #error "Only <gtk/gtk.h> can be included directly."
 #endif
 
@@ -26,9 +26,6 @@
 
 #include <glib-object.h>
 
-/* Not needed, retained for compatibility -Yosh */
-#include <gtk/gtkobject.h>
-
 G_BEGIN_DECLS
 
 #define GTK_TYPE_TREE_MODEL            (gtk_tree_model_get_type ())
@@ -134,8 +131,10 @@ void         gtk_tree_path_prepend_index    (GtkTreePath       *path,
 					     gint               index_);
 gint         gtk_tree_path_get_depth        (GtkTreePath       *path);
 gint        *gtk_tree_path_get_indices      (GtkTreePath       *path);
+
 gint        *gtk_tree_path_get_indices_with_depth (GtkTreePath *path,
-                                                   gint        *depth);
+						   gint        *depth);
+
 void         gtk_tree_path_free             (GtkTreePath       *path);
 GtkTreePath *gtk_tree_path_copy             (const GtkTreePath *path);
 GType        gtk_tree_path_get_type         (void) G_GNUC_CONST;
@@ -151,10 +150,6 @@ gboolean     gtk_tree_path_is_ancestor      (GtkTreePath       *path,
 gboolean     gtk_tree_path_is_descendant    (GtkTreePath       *path,
                                              GtkTreePath       *ancestor);
 
-#ifndef GTK_DISABLE_DEPRECATED
-#define gtk_tree_path_new_root() gtk_tree_path_new_first()
-#endif /* !GTK_DISABLE_DEPRECATED */
-
 /* Row reference (an object that tracks model changes so it refers to the same
  * row always; a path refers to a position, not a fixed row).  You almost always
  * want to call gtk_tree_row_reference_new.
@@ -243,11 +238,6 @@ void              gtk_tree_model_foreach         (GtkTreeModel            *model
 						  GtkTreeModelForeachFunc  func,
 						  gpointer                 user_data);
 
-
-#ifndef GTK_DISABLE_DEPRECATED
-#define gtk_tree_model_get_iter_root(tree_model, iter) gtk_tree_model_get_iter_first(tree_model, iter)
-#endif /* !GTK_DISABLE_DEPRECATED */
-
 /* Signals */
 void gtk_tree_model_row_changed           (GtkTreeModel *tree_model,
 					   GtkTreePath  *path,
