@@ -18,8 +18,6 @@
  * Boston, MA 02111-1307, USA.
  */
 
-#undef GTK_DISABLE_DEPRECATED
-#define GTK_ENABLE_BROKEN
 #include <string.h>
 #include <gtk/gtk.h>
 #include <gtk/gtkunixprint.h>
@@ -77,6 +75,7 @@ test_type (gconstpointer data)
 
   /* These can't be freely constructed/destroyed */
   if (g_type_is_a (type, GTK_TYPE_PRINT_JOB) ||
+      g_type_is_a (type, GTK_TYPE_APPLICATION) ||
       g_type_is_a (type, GDK_TYPE_PIXBUF_LOADER) ||
       g_type_is_a (type, gdk_pixbuf_simple_anim_iter_get_type ()))
     return;
@@ -85,12 +84,6 @@ test_type (gconstpointer data)
   
   if (g_type_is_a (type, GTK_TYPE_SETTINGS))
     instance = g_object_ref (gtk_settings_get_default ());
-  else if (g_type_is_a (type, GDK_TYPE_PANGO_RENDERER))
-    instance = g_object_ref (gdk_pango_renderer_get_default (gdk_screen_get_default ()));
-  else if (g_type_is_a (type, GDK_TYPE_PIXMAP))
-    instance = g_object_ref (gdk_pixmap_new (NULL, 1, 1, 1));
-  else if (g_type_is_a (type, GDK_TYPE_COLORMAP))
-    instance = g_object_ref (gdk_colormap_new (gdk_visual_get_best (), TRUE));
   else if (g_type_is_a (type, GDK_TYPE_WINDOW))
     {
       GdkWindowAttr attributes;
@@ -122,10 +115,6 @@ test_type (gconstpointer data)
 	  (strcmp (pspec->name, "default-display") == 0))
 	continue;
 
-      if (g_type_is_a (type, GDK_TYPE_PANGO_RENDERER) &&
-	  (strcmp (pspec->name, "screen") == 0))
-	continue;
-
       if (g_type_is_a (type, GTK_TYPE_ABOUT_DIALOG) &&
 	  (strcmp (pspec->name, "program-name") == 0))
 	continue;
@@ -180,7 +169,12 @@ test_type (gconstpointer data)
 	continue;
 
       if (g_type_is_a (type, GTK_TYPE_MESSAGE_DIALOG) &&
-	  strcmp (pspec->name, "image") == 0)
+          (strcmp (pspec->name, "image") == 0 ||
+           strcmp (pspec->name, "message-area") == 0))
+	continue;
+
+      if (g_type_is_a (type, GTK_TYPE_PANED) &&
+	  strcmp (pspec->name, "max-position") == 0)
 	continue;
 
       if (g_type_is_a (type, GTK_TYPE_PRINT_OPERATION) &&
