@@ -1,9 +1,27 @@
-#undef GTK_DISABLE_DEPRECATED
-#include <config.h>
+/* testtreeview.c
+ * Copyright (C) 2001 Red Hat, Inc
+ * Author: Jonathan Blandford
+ *
+ * This library is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU Library General Public
+ * License as published by the Free Software Foundation; either
+ * version 2 of the License, or (at your option) any later version.
+ *
+ * This library is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * Library General Public License for more details.
+ *
+ * You should have received a copy of the GNU Library General Public
+ * License along with this library; if not, write to the
+ * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
+ * Boston, MA 02111-1307, USA.
+ */
+
 #include <string.h>
 #include "prop-editor.h"
 #include <gtk/gtk.h>
-
+#include <stdlib.h>
 
 /* Don't copy this bad example; inline RGB data is always a better
  * idea than inline XPMs.
@@ -239,6 +257,66 @@ toggled_callback (GtkCellRendererToggle *celltoggle,
                g_type_name (G_TYPE_FROM_INSTANCE (model)));
 }
 
+static void
+edited_callback (GtkCellRendererText *renderer,
+		 const gchar   *path_string,
+		 const gchar   *new_text,
+		 GtkTreeView  *tree_view)
+{
+  GtkTreeModel *model = NULL;
+  GtkTreeModelSort *sort_model = NULL;
+  GtkTreePath *path;
+  GtkTreeIter iter;
+  guint value = atoi (new_text);
+  
+  g_return_if_fail (GTK_IS_TREE_VIEW (tree_view));
+
+  model = gtk_tree_view_get_model (tree_view);
+  
+  if (GTK_IS_TREE_MODEL_SORT (model))
+    {
+      sort_model = GTK_TREE_MODEL_SORT (model);
+      model = gtk_tree_model_sort_get_model (sort_model);
+    }
+
+  if (model == NULL)
+    return;
+
+  if (sort_model)
+    {
+      g_warning ("FIXME implement conversion from TreeModelSort iter to child model iter");
+      return;
+    }
+      
+  path = gtk_tree_path_new_from_string (path_string);
+  if (!gtk_tree_model_get_iter (model,
+                                &iter, path))
+    {
+      g_warning ("%s: bad path?", G_STRLOC);
+      return;
+    }
+  gtk_tree_path_free (path);
+
+  if (GTK_IS_LIST_STORE (model))
+    {
+      gtk_list_store_set (GTK_LIST_STORE (model),
+                          &iter,
+                          4,
+                          value,
+                          -1);
+    }
+  else if (GTK_IS_TREE_STORE (model))
+    {
+      gtk_tree_store_set (GTK_TREE_STORE (model),
+                          &iter,
+                          4,
+                          value,
+                          -1);
+    }
+  else
+    g_warning ("don't know how to actually toggle value for model type %s",
+               g_type_name (G_TYPE_FROM_INSTANCE (model)));
+}
 
 static ColumnsType current_column_type = COLUMNS_LOTS;
 
@@ -249,7 +327,8 @@ set_columns_type (GtkTreeView *tree_view, ColumnsType type)
   GtkCellRenderer *rend;
   GdkPixbuf *pixbuf;
   GtkWidget *image;
-  
+  GtkAdjustment *adjustment;
+
   current_column_type = type;
   
   col = gtk_tree_view_get_column (tree_view, 0);
@@ -339,19 +418,25 @@ set_columns_type (GtkTreeView *tree_view, ColumnsType type)
       setup_column (col);
       
       gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), col);
-      
-#if 0
 
-      rend = gtk_cell_renderer_text_new ();
-      
+      rend = gtk_cell_renderer_spin_new ();
+
+      adjustment = gtk_adjustment_new (0, 0, 10000, 100, 100, 100);
+      g_object_set (rend, "editable", TRUE, NULL);
+      g_object_set (rend, "adjustment", adjustment, NULL);
+
+      g_signal_connect (rend, "edited",
+			G_CALLBACK (edited_callback), tree_view);
+
       col = gtk_tree_view_column_new_with_attributes ("Column 5",
                                                       rend,
-                                                      "text", 3,
+                                                      "text", 4,
                                                       NULL);
 
       setup_column (col);
       
       gtk_tree_view_append_column (GTK_TREE_VIEW (tree_view), col);
+#if 0
       
       rend = gtk_cell_renderer_text_new ();
       
@@ -572,12 +657,12 @@ create_tree_model (void)
 }
 
 static void
-model_selected (GtkOptionMenu *om, gpointer data)
+model_selected (GtkComboBox *combo_box, gpointer data)
 {
   GtkTreeView *tree_view = GTK_TREE_VIEW (data);
   gint hist;
 
-  hist = gtk_option_menu_get_history (om);
+  hist = gtk_combo_box_get_active (combo_box);
 
   if (models[hist] != gtk_tree_view_get_model (tree_view))
     {
@@ -586,12 +671,12 @@ model_selected (GtkOptionMenu *om, gpointer data)
 }
 
 static void
-columns_selected (GtkOptionMenu *om, gpointer data)
+columns_selected (GtkComboBox *combo_box, gpointer data)
 {
   GtkTreeView *tree_view = GTK_TREE_VIEW (data);
   gint hist;
 
-  hist = gtk_option_menu_get_history (om);
+  hist = gtk_combo_box_get_active (combo_box);
 
   if (hist != get_columns_type ())
     {
@@ -618,8 +703,7 @@ main (int    argc,
   GtkWidget *sw;
   GtkWidget *tv;
   GtkWidget *table;
-  GtkWidget *om;
-  GtkWidget *menu;
+  GtkWidget *combo_box;
   GtkTreeModel *model;
   gint i;
   
@@ -650,7 +734,7 @@ main (int    argc,
   
   window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
   g_signal_connect (window, "destroy", G_CALLBACK (gtk_main_quit), NULL);
-  gtk_window_set_default_size (GTK_WINDOW (window), 400, 400);
+  gtk_window_set_default_size (GTK_WINDOW (window), 430, 400);
 
   table = gtk_table_new (3, 1, FALSE);
 
@@ -670,77 +754,34 @@ main (int    argc,
 					GDK_ACTION_MOVE | GDK_ACTION_COPY);
   
   /* Model menu */
-
-  menu = gtk_menu_new ();
+  combo_box = gtk_combo_box_new_text ();
+  for (i = 0; i < MODEL_LAST; i++)
+      gtk_combo_box_append_text (GTK_COMBO_BOX (combo_box), model_names[i]);
   
-  i = 0;
-  while (i < MODEL_LAST)
-    {
-      GtkWidget *mi;
-      const char *name;
-
-      name = model_names[i];
-      
-      mi = gtk_menu_item_new_with_label (name);
-
-      gtk_menu_shell_append (GTK_MENU_SHELL (menu), mi);
-
-#if 0
-      window = create_prop_editor (G_OBJECT (models[i]));
-
-      gtk_window_set_title (GTK_WINDOW (window),                            
-                            name);
-#endif
-
-      ++i;
-    }
-  gtk_widget_show_all (menu);
-  
-  om = gtk_option_menu_new ();
-  gtk_option_menu_set_menu (GTK_OPTION_MENU (om), menu);
-  
-  gtk_table_attach (GTK_TABLE (table), om,
+  gtk_table_attach (GTK_TABLE (table), combo_box,
                     0, 1, 0, 1,
                     0, 0, 
                     0, 0);
 
-  g_signal_connect (om,
+  g_signal_connect (combo_box,
                     "changed",
                     G_CALLBACK (model_selected),
 		    tv);
   
   /* Columns menu */
-
-  menu = gtk_menu_new ();
+  combo_box = gtk_combo_box_new_text ();
+  for (i = 0; i < COLUMNS_LAST; i++)
+      gtk_combo_box_append_text (GTK_COMBO_BOX (combo_box), column_type_names[i]);
   
-  i = 0;
-  while (i < COLUMNS_LAST)
-    {
-      GtkWidget *mi;
-      const char *name;
-
-      name = column_type_names[i];
-      
-      mi = gtk_menu_item_new_with_label (name);
-
-      gtk_menu_shell_append (GTK_MENU_SHELL (menu), mi);
-
-      ++i;
-    }
-  gtk_widget_show_all (menu);
-  
-  om = gtk_option_menu_new ();
-  gtk_option_menu_set_menu (GTK_OPTION_MENU (om), menu);
-  
-  gtk_table_attach (GTK_TABLE (table), om,
+  gtk_table_attach (GTK_TABLE (table), combo_box,
                     0, 1, 1, 2,
                     0, 0, 
                     0, 0);
 
   set_columns_type (GTK_TREE_VIEW (tv), COLUMNS_LOTS);
-  gtk_option_menu_set_history (GTK_OPTION_MENU (om), COLUMNS_LOTS);
-  
-  g_signal_connect (om,
+  gtk_combo_box_set_active (GTK_COMBO_BOX (combo_box), COLUMNS_LOTS);
+
+  g_signal_connect (combo_box,
                     "changed",
                     G_CALLBACK (columns_selected),
                     tv);
@@ -805,7 +846,7 @@ gtk_tree_model_types_get_type (void)
 
   if (!model_types_type)
     {
-      static const GTypeInfo model_types_info =
+      const GTypeInfo model_types_info =
       {
         sizeof (GtkTreeModelTypesClass),
 	NULL,		/* base_init */
@@ -818,7 +859,7 @@ gtk_tree_model_types_get_type (void)
         (GInstanceInitFunc) gtk_tree_model_types_init
       };
 
-      static const GInterfaceInfo tree_model_info =
+      const GInterfaceInfo tree_model_info =
       {
 	(GInterfaceInitFunc) gtk_tree_model_types_tree_model_init,
 	NULL,
@@ -964,7 +1005,7 @@ gtk_real_model_types_get_value (GtkTreeModel *tree_model,
         
         g_value_init (value, G_TYPE_STRING);
 
-        str = g_strdup_printf ("%ld", type);
+        str = g_strdup_printf ("%ld", (long int) type);
         g_value_set_string (value, str);
         g_free (str);
       }
@@ -1163,7 +1204,9 @@ gtk_real_model_types_iter_parent (GtkTreeModel *tree_model,
   if (parent == G_TYPE_INVALID)
     {
       if (type > G_TYPE_FUNDAMENTAL_MAX)
-        g_warning ("no parent for %ld %s\n", type, g_type_name (type));
+        g_warning ("no parent for %ld %s\n",
+                   (long int) type,
+                   g_type_name (type));
       return FALSE;
     }
   else
@@ -1178,6 +1221,8 @@ gtk_real_model_types_iter_parent (GtkTreeModel *tree_model,
  * Automated testing
  */
 
+#if 0
+
 static void
 treestore_torture_recurse (GtkTreeStore *store,
                            GtkTreeIter  *root,
@@ -1267,6 +1312,8 @@ treestore_torture_recurse (GtkTreeStore *store,
     }
 }
 
+#endif
+
 static void
 run_automated_tests (void)
 {
